@@ -3,7 +3,7 @@
 //                               ----------------                             *
 //  Description : This class does the command line processing.                *
 //  Started     : 22/02/2005                                                  *
-//  Last Update : 07/12/2006                                                  *
+//  Last Update : 22/02/2008                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -51,6 +51,7 @@ class CmdLinePcr : wxCmdLineParser
     wxString       m_osSimrType;
     wxString       m_osAnaType;
     wxString       m_osGuileProc;
+    wxString       m_osViewer;
     wxString       m_osConfigFile;
     wxString       m_osNetLstFile;
     wxArrayString  m_oasSchemFiles;
@@ -61,6 +62,7 @@ class CmdLinePcr : wxCmdLineParser
     bool  bProcOption_r( int * piArg );  // Specify a configuration file
     bool  bProcOption_s( int * piArg );  // Simulator engine specifier
     bool  bProcOption_v( int * piArg );  // Display app. version and exit
+    bool  bProcOption_w( int * piArg );  // Specify the waveform viewer to use
     bool  bProcSchems  ( int * piArg );  // Schematic file name/s
     bool  bProcNetList ( int * piArg );  // Net list file name
 
