@@ -4,7 +4,7 @@
 //  Description : This header file mostly contains enumerated type            *
 //                definitions which may be used anywhere in the application.  *
 //  Started     : 06/09/2007                                                  *
-//  Last Update : 15/10/2007                                                  *
+//  Last Update : 23/01/2008                                                  *
 //  Copyright   : (C) 2007 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -21,6 +21,9 @@
 #ifndef TYPEDEFS_HPP
 #define TYPEDEFS_HPP
 
+#include <wx/filename.h>
+#include <wx/dynarray.h>
+
 //*****************************************************************************
 // Fonts
 
@@ -44,6 +47,18 @@ enum eSimrType
   eSIMR_LST = eSIMR_NGSPICE
 };
 
+// Enumerated type for the various waveform viewers types
+enum eViewType
+{
+  eVIEW_GWAVE,  // GWave
+  eVIEW_GAW,    // Gaw
+
+  eVIEW_NONE,   // Used if a waveform viewer has not yet been selected
+
+  eVIEW_FST = eVIEW_GWAVE,
+  eVIEW_LST = eVIEW_GAW
+};
+
 // Enumerated type for the various analyses types which may be performed
 enum eAnaType
 {
@@ -122,4 +137,8 @@ enum  eInitCType
 
 //*****************************************************************************
 
+WX_DECLARE_OBJARRAY( wxFileName, ArrayFileName );
+
+//*****************************************************************************
+
 #endif // TYPEDEFS_HPP
