@@ -5,7 +5,7 @@
 //                characteristics of structure in that some attributes have   *
 //                public access; this simplifies the classes interface.       *
 //  Started     : 31/08/2006                                                  *
-//  Last Update : 23/08/2007                                                  *
+//  Last Update : 30/01/2008                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -24,6 +24,8 @@
 
 // System Includes
 
+using  namespace  std;
+
 #include <iostream>
 
 // wxWidgets Includes
@@ -38,16 +40,13 @@
 
 //*****************************************************************************
 
-class CmdBase : public wxString
+struct CmdBase : public wxString
 {
-  protected:
+  protected :
 
     bool  m_bIsOk;
 
-    virtual  bool  bParse ( void ) = 0;
-    virtual  bool  bFormat( void ) = 0;
-
-  public:
+  public :
 
     wxString  m_osName;
 
@@ -57,8 +56,10 @@ class CmdBase : public wxString
     bool  bClear( void );
     bool  bIsOk( void ) { return( m_bIsOk ); }
 
-    wxString & rosGetCmd( void );
-    bool         bSetCmd( const wxString & rosCmd );
+    virtual  bool  bParse ( void ) = 0;
+    virtual  bool  bFormat( void ) = 0;
+
+    void  Print( const char * psPrefix="" );
 };
 
 //*****************************************************************************
