@@ -2,7 +2,7 @@
 //                              DlgGnuCapOPT.cpp                              *
 //                             ------------------                             *
 //  Started     : 14/09/2006                                                  *
-//  Last Update : 09/10/2007                                                  *
+//  Last Update : 12/12/2007                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -741,7 +741,9 @@ bool  DlgGnuCapOPT::bClear( void )
 
 bool  DlgGnuCapOPT::bSetCmd( const wxString & rosCmd )
 {
-  if( CmdBase::bSetCmd( rosCmd ) ) return( FALSE );
+  CmdGnuCapOPT::bClear( );
+  *((wxString *) this) = rosCmd;
+  if( ! CmdGnuCapOPT::bParse( ) ) return( FALSE );
 
   SetValues( );
 
