@@ -2,7 +2,7 @@
 //                                DlgPrefs.cpp                                *
 //                               --------------                               *
 //  Started     : 17/10/2006                                                  *
-//  Last Update : 28/06/2007                                                  *
+//  Last Update : 28/02/2008                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -75,32 +75,43 @@ void  DlgPrefs::Initialize( void )
 
 void  DlgPrefs::Create( void )
 {
-  wxPanel * poPnl, * poPnl_TFM;
+  wxPanel * poPnl, * poPnlWaveViewer, * poPnlTmpFileMgt;
 
   // Create the preferences panel and controls
   poPnl = new wxPanel( this );
 
+  // Create the waveform viewer panel and controls
+  poPnlWaveViewer = new wxPanel( poPnl );
+  m_oLblWaveViewer.Create( poPnlWaveViewer, ID_UNUSED, wxT("Waveform Viewer"),
+                       wxDefaultPosition, wxSize( 130, -1 ),
+                       wxST_NO_AUTORESIZE );
+  m_oChoWaveViewer.Create( poPnlWaveViewer, ID_CHO_WAVEVIEWER, wxDefaultPosition,
+                           wxSize( 95, -1 ) );
+  m_oChoWaveViewer.Append( wxT("GWave") );
+  m_oChoWaveViewer.Append( wxT("Gaw") );
+  m_oChoWaveViewer.SetSelection( 0 );
+
   // Create the temporary file management panel and controls
-  poPnl_TFM = new wxPanel( poPnl );
-  m_oLblTmpFileMgt.Create( poPnl_TFM, ID_UNUSED, wxT("Temporary Files"),
-                           wxDefaultPosition, wxSize( 110, -1 ),
+  poPnlTmpFileMgt = new wxPanel( poPnl );
+  m_oLblTmpFileMgt.Create( poPnlTmpFileMgt, ID_UNUSED, wxT("Temporary Files"),
+                           wxDefaultPosition, wxSize( 130, -1 ),
                            wxST_NO_AUTORESIZE );
-  m_oChoTmpFileMgt.Create( poPnl_TFM, ID_CHO_TMPFILEMGT, wxDefaultPosition,
+  m_oChoTmpFileMgt.Create( poPnlTmpFileMgt, ID_CHO_TMPFILEMGT, wxDefaultPosition,
                            wxSize( 95, -1 ) );
   m_oChoTmpFileMgt.Append( wxT("Delete") );
   m_oChoTmpFileMgt.Append( wxT("Prompt") );
   m_oChoTmpFileMgt.Append( wxT("Keep") );
-  m_oChoTmpFileMgt.SetStringSelection( wxT("Delete") );
+  m_oChoTmpFileMgt.SetSelection( 0 );
 
   // Create the PnlValue controls
-  m_oPnlMaxLines.bCreate( poPnl, ID_PNL_MAXLINES, 105, wxDefaultPosition, FALSE );
+  m_oPnlMaxLines.bCreate( poPnl, ID_PNL_MAXLINES, 125, wxDefaultPosition, FALSE );
   m_oPnlMaxLines.bSetName( wxT("Maximum Lines") );
   m_oPnlMaxLines.bSetVarType( SpinCtrl::eVAR_INT );
   m_oPnlMaxLines.bShowUnits( FALSE );
   m_oPnlMaxLines.bSetParms( TXTCTL_LINESDEF, TXTCTL_LINESMIN, TXTCTL_LINESMAX );
 
   // Create the tool tips check box
-  m_oCbxToolTips.Create( poPnl, ID_CBX_TOOLTIPS, wxT("Show Tool Tips\t  "),
+  m_oCbxToolTips.Create( poPnl, ID_CBX_TOOLTIPS, wxT("Show Tool Tips\t\t"),
                          wxDefaultPosition, wxSize( -1, PNLVALUE_HT ),
                          wxALIGN_RIGHT );
 
@@ -125,8 +136,8 @@ void  DlgPrefs::ToolTips( void )
 
 void  DlgPrefs::DoLayout( void )
 {
-  wxPanel     * poPnlCtrls, * poPnl_TFM, * poPnlBtns;
-  wxSizer     * poSzrCtrls, * poSzr_TFM, * poSzrBtns;
+  wxPanel     * poPnlCtrls, * poPnlWaveViewer, * poPnlTmpFileMgt, * poPnlBtns;
+  wxSizer     * poSzrCtrls, * poSzrWaveViewer, * poSzrTmpFileMgt, * poSzrBtns;
   wxSizerFlags  oFlags, oFlags2;  // ??? (06/06/2007) Need oFlags2 owing to a bug in wxWidgets
 
   // Create and set the underlying dialog's sizer
@@ -137,23 +148,36 @@ void  DlgPrefs::DoLayout( void )
   poSzrCtrls = new wxStaticBoxSizer( wxVERTICAL, poPnlCtrls );
   poPnlCtrls->SetSizer( poSzrCtrls );
 
+  // Create and set the wave veiwer sizer
+  poPnlWaveViewer = (wxPanel *) m_oChoWaveViewer.GetParent( );
+  poSzrWaveViewer = new wxBoxSizer( wxHORIZONTAL );
+  poPnlWaveViewer->SetSizer( poSzrWaveViewer );
+
+  // Layout the wave veiwer panel
+  oFlags.Align( wxALIGN_CENTER );
+  oFlags.Border( wxTOP | wxBOTTOM, 1 );
+  poSzrWaveViewer->Add( &m_oLblWaveViewer, oFlags );
+  poSzrWaveViewer->Add( &m_oChoWaveViewer, oFlags );
+  poSzrWaveViewer->SetSizeHints( poPnlWaveViewer );
+
   // Create and set the temporary file management strategy sizer
-  poPnl_TFM = (wxPanel *) m_oChoTmpFileMgt.GetParent( );
-  poSzr_TFM = new wxBoxSizer( wxHORIZONTAL );
-  poPnl_TFM->SetSizer( poSzr_TFM );
+  poPnlTmpFileMgt = (wxPanel *) m_oChoTmpFileMgt.GetParent( );
+  poSzrTmpFileMgt = new wxBoxSizer( wxHORIZONTAL );
+  poPnlTmpFileMgt->SetSizer( poSzrTmpFileMgt );
 
   // Layout the temporary file management strategy panel
   oFlags.Align( wxALIGN_CENTER );
   oFlags.Border( wxTOP | wxBOTTOM, 1 );
-  poSzr_TFM->Add( &m_oLblTmpFileMgt, oFlags );
-  poSzr_TFM->Add( &m_oChoTmpFileMgt, oFlags );
-  poSzr_TFM->SetSizeHints( poPnl_TFM );
+  poSzrTmpFileMgt->Add( &m_oLblTmpFileMgt, oFlags );
+  poSzrTmpFileMgt->Add( &m_oChoTmpFileMgt, oFlags );
+  poSzrTmpFileMgt->SetSizeHints( poPnlTmpFileMgt );
 
   // Layout the preferences controls
   oFlags2.Align( wxALIGN_LEFT );
   oFlags2.Border( wxTOP | wxLEFT | wxRIGHT, 10 );
-  poSzrCtrls->Add( poPnl_TFM,       oFlags2 );
+  poSzrCtrls->Add( poPnlWaveViewer, oFlags2 );
   oFlags2.Border( wxLEFT | wxRIGHT,         10 );
+  poSzrCtrls->Add( poPnlTmpFileMgt, oFlags2 );
   poSzrCtrls->Add( &m_oPnlMaxLines, oFlags2 );
   oFlags2.Border( wxTOP | wxBOTTOM | wxLEFT, 8 );
   poSzrCtrls->Add( &m_oCbxToolTips, oFlags2 );
@@ -194,6 +218,11 @@ void  DlgPrefs::SetValues( void )
 
   SetEvtHandlerEnabled( FALSE );
 
+  m_poConfig->SetPath( wxT("/Viewer") );
+
+  m_poConfig->Read( wxT("Name"),        &os1, wxT("GWave") );
+  m_oChoWaveViewer.SetStringSelection( os1 );
+
   m_poConfig->SetPath( wxT("/Main") );
 
   m_poConfig->Read( wxT("NbkMaxLines"), &li1, (long) TXTCTL_LINESDEF );
@@ -219,14 +248,19 @@ void  DlgPrefs::GetValues( void )
 
   SetEvtHandlerEnabled( FALSE );
 
-  m_poConfig->SetPath( wxT("/Main") );
+  m_poConfig->SetPath( wxT("/Viewer") );
 
-  li1 = m_oPnlMaxLines.liGetValue( );
-  m_poConfig->Write( wxT("NbkMaxLines"), li1 );
+  os1 = m_oChoWaveViewer.GetStringSelection( );
+  m_poConfig->Write( wxT("Name"),  os1 );
+
+  m_poConfig->SetPath( wxT("/Main") );
 
   os1 = m_oChoTmpFileMgt.GetStringSelection( );
   m_poConfig->Write( wxT("TmpFileMgt"),  os1 );
 
+  li1 = m_oPnlMaxLines.liGetValue( );
+  m_poConfig->Write( wxT("NbkMaxLines"), li1 );
+
   li1 = ( m_oCbxToolTips.GetValue( ) ? 1 : 0 );
   m_poConfig->Write( wxT("ToolTips"),    li1 );
   wxToolTip::Enable( li1 != 0 ? TRUE : FALSE );
