@@ -2,7 +2,7 @@
 //                                FileTasks.cpp                               *
 //                               ---------------                              *
 //  Started     : 28/05/2005                                                  *
-//  Last Update : 04/10/2007                                                  *
+//  Last Update : 19/02/2008                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -22,7 +22,7 @@
 //*****************************************************************************
 // Constructor.
 //
-// Argument List:
+// Argument List :
 //   poFrmMain - A pointer to the parent frame
 
 FileTasks::FileTasks( FrmMain * poFrmMain )
@@ -50,7 +50,7 @@ FileTasks::~FileTasks( )
 //*****************************************************************************
 // Display an open file dialog and set the net list file name.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -104,7 +104,7 @@ bool  FileTasks::bDlgOpen( void )
 //*****************************************************************************
 // Display an import file/s dialog and set the schematic file name/s.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -159,7 +159,7 @@ bool  FileTasks::bDlgImport( void )
 //*****************************************************************************
 // Execute the schematic import process.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -223,8 +223,8 @@ void  FileTasks::InitGuileProc( void )
 void  FileTasks::InitSchemFiles( void )
 {
   wxStringTokenizer  ostk1;
-  wxArrayString  oas1;
-  wxString  os1;
+  wxArrayString      oas1;
+  wxString           os1;
 
   // Get the net list name
   m_poConfig->SetPath( wxT("/Files") );
@@ -240,9 +240,12 @@ void  FileTasks::InitSchemFiles( void )
     if( bSetSchemFiles( oas1 ) )
       if( m_poFrmMain->m_oSim.IsEmpty( ) )
         if( bReload( m_poFrmMain->m_oSim ) )
-          if( m_poFrmMain->bReloadSim( ) )
+          if( m_poFrmMain->bSimReload( ) )
             m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
   }
+
+  // Set the schematic file name/s in the schematic editor
+  m_poFrmMain->m_oPrcGSchem.bSetSchems( roasGetSchemFiles( ) );
 }
 
 //*****************************************************************************
@@ -260,7 +263,7 @@ void  FileTasks::InitNetLstFile( void )
   if( ! os1.IsEmpty( ) )
     if( bSetNetLstFile( os1 ) )
       if( bReload( m_poFrmMain->m_oSim ) )
-        if( m_poFrmMain->bReloadSim( ) )
+        if( m_poFrmMain->bSimReload( ) )
           m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
 }
 
@@ -302,18 +305,18 @@ void  FileTasks::DlgSchemsErr( void )
 //*****************************************************************************
 // Delete temporary files which may have been generated by this application.
 // Ie. given the circuit description file "<netlist>.ckt" delete files of the
-//     following form:
+//     following form :
 //       <netlist>.ngspice.DC, <netlist>.ngspice.AC, etc.
-//       <netlist>.gnucap.OP, <netlist>.gnucap.DC, etc.
+//       <netlist>.gnucap.OP,  <netlist>.gnucap.DC,  etc.
 //       gnetlist.log
 
 bool  FileTasks::bDelTmpFiles( void )
 {
   wxArrayString  oas1;
-  wxFileName  ofn1;
-  wxString  os1, os2;
-  size_t  szt1;
-  int  i1;
+  wxFileName     ofn1;
+  wxString       os1, os2;
+  size_t         szt1;
+  int            i1;
 
   if( m_eTmpFileMgt == eTFM_KEEP ) return( TRUE );
 
@@ -374,7 +377,7 @@ bool  FileTasks::bDelTmpFiles( void )
 //*****************************************************************************
 // Clear the object attributes.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -401,7 +404,7 @@ void  FileTasks::Initialize( void )
 // Check that the gNetList binary can be found, if not display an error
 // message.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -428,7 +431,7 @@ bool  FileTasks::bIsOkGNetList( void )
 //*****************************************************************************
 // Set the application main frame title.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -463,7 +466,7 @@ bool  FileTasks::bSetTitle( void )
 // Set a Guile procedure name to be used for importing schematic files using
 // GNetList.
 //
-// Argument List:
+// Argument List :
 //   rosProcName - The Guile procedure name
 //                 (Refer to GNetList documentation for list of procedure names)
 
@@ -475,17 +478,17 @@ bool  FileTasks::bSetGuileProc( const wxString & rosProcName )
 //*****************************************************************************
 // Set the schematic file name/s.
 //
-// Argument List:
+// Argument List :
 //   roasFileName - A string array containing the full path and file name/s
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  FileTasks::bSetSchemFiles( const wxArrayString & roasFileNames )
 {
   wxString  os1;
-  size_t  szt1;
+  size_t    szt1;
 
   if( ! m_oPrcGNetList.bSetSchems( roasFileNames ) ) return( FALSE );
 
@@ -508,10 +511,10 @@ bool  FileTasks::bSetSchemFiles( const wxArrayString & roasFileNames )
 //*****************************************************************************
 // Set the net list file name.
 //
-// Argument List:
+// Argument List :
 //   psFileName - A string containing the full path and file name
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -534,10 +537,10 @@ bool  FileTasks::bSetNetLstFile( const wxString & rosFileName )
 //*****************************************************************************
 // Set the temporary file management strategy on close or exit.
 //
-// Argument List:
+// Argument List :
 //   eTmpFileMgt - An enumerated type indicating what to do with temp. files
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -553,7 +556,7 @@ bool  FileTasks::bSetTmpFileMgt( eTmpFMgtType eTFM )
 //*****************************************************************************
 // Get the currently selected Guile procedure.
 //
-// Return Values:
+// Return Values :
 //   The currently selected Guile procedure
 
 const wxString & FileTasks::rosGetGuileProc( void )
@@ -564,7 +567,7 @@ const wxString & FileTasks::rosGetGuileProc( void )
 //*****************************************************************************
 // Get an array containing the schematic file name/s.
 //
-// Return Values:
+// Return Values :
 //   An array of schematic file names
 
 const wxArrayString & FileTasks::roasGetSchemFiles( void )
@@ -587,7 +590,7 @@ const wxArrayString & FileTasks::roasGetSchemFiles( void )
 //*****************************************************************************
 // Get the net list file name.
 //
-// Return Values:
+// Return Values :
 //   The net list file name
 
 const wxString & FileTasks::rosGetNetLstFile( void )
@@ -603,10 +606,10 @@ const wxString & FileTasks::rosGetNetLstFile( void )
 // Open and load a circuit description (net list) file into a Simulation
 // object.
 //
-// Argument List:
+// Argument List :
 //   roSim - The Simulation object to be loaded
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -646,22 +649,22 @@ bool  FileTasks::bOpen( Simulation & roSim )
 // Import a schematic file by converting it to a net list using GNetList and
 // then loading it into a Simulation object.
 //
-// Argument List:
+// Argument List :
 //   roSim - The Simulation object to be loaded
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  FileTasks::bImport( Simulation & roSim )
 {
-  bool  bRtnValue=TRUE;
+  bool  bRtnValue=FALSE;
 
   // Check that gNetList binary exists and is accessible
-  if( ! bIsOkGNetList( ) ) return( FALSE );
+  if( ! bIsOkGNetList( ) )   return( FALSE );
 
   // Get the schematic file name/s from the user
-  if( ! bDlgImport( ) )    return( FALSE );
+  if( ! bDlgImport( ) )      return( FALSE );
 
   // Change the cursor to the wait symbol
   ::wxBeginBusyCursor( );
@@ -670,16 +673,12 @@ bool  FileTasks::bImport( Simulation & roSim )
   m_poFrmMain->bClear( );
 
   // Convert the schematic file/s to a net list file and load it
-  if( ! bExecImport( ) )
+  if( bExecImport( ) )
   {
-    bRtnValue = FALSE;
-    DlgSchemsErr( );
-  }
-  else if( ! roSim.bLoadFile( ) )
-  {
-    bRtnValue = FALSE;
-    DlgNetLstErr( );
+    if( roSim.bLoadFile( ) ) bRtnValue = TRUE;
+    else DlgNetLstErr( );
   }
+  else DlgSchemsErr( );
 
   // Change the cursor to the default
   ::wxEndBusyCursor( );
@@ -690,7 +689,7 @@ bool  FileTasks::bImport( Simulation & roSim )
 //*****************************************************************************
 // Reload a Simulation object whether it be from a schematic or net list file.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -750,7 +749,7 @@ bool  FileTasks::bReload( Simulation & roSim )
 //*****************************************************************************
 // Close the circuit description file.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -767,7 +766,7 @@ bool  FileTasks::bClose( void )
 //*****************************************************************************
 // Do the necessary tasks before the application exits.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
