@@ -2,7 +2,7 @@
 //                                FrmMain.cpp                                 *
 //                               -------------                                *
 //  Started     : 18/08/2003                                                  *
-//  Last Update : 25/10/2007                                                  *
+//  Last Update : 29/02/2008                                                  *
 //  Copyright   : (C) 2003 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -29,6 +29,7 @@
   #include "icons/sim-create.xpm"
   #include "icons/sim-run.xpm"
   #include "icons/sim-stop.xpm"
+  #include "icons/sim-edit.xpm"
   #include "icons/sim-plot.xpm"
   #include "icons/help.xpm"
 #endif
@@ -48,6 +49,7 @@ BEGIN_EVENT_TABLE( FrmMain, wxFrame )
   EVT_MENU( ID_MNU_CREATE,  FrmMain::OnSimCreate )
   EVT_MENU( ID_MNU_RUN,     FrmMain::OnSimRun    )
   EVT_MENU( ID_MNU_STOP,    FrmMain::OnSimStop   )
+  EVT_MENU( ID_MNU_EDIT,    FrmMain::OnEdit      )
   EVT_MENU( ID_MNU_PLOT,    FrmMain::OnPlot      )
   EVT_MENU( ID_MNU_GNUCAP,  FrmMain::OnSelSimr   )
   EVT_MENU( ID_MNU_NGSPICE, FrmMain::OnSelSimr   )
@@ -62,6 +64,7 @@ BEGIN_EVENT_TABLE( FrmMain, wxFrame )
   EVT_TOOL( ID_TBR_CREATE,  FrmMain::OnSimCreate )
   EVT_TOOL( ID_TBR_RUN,     FrmMain::OnSimRun    )
   EVT_TOOL( ID_TBR_STOP,    FrmMain::OnSimStop   )
+  EVT_TOOL( ID_TBR_EDIT,    FrmMain::OnEdit      )
   EVT_TOOL( ID_TBR_PLOT,    FrmMain::OnPlot      )
   EVT_TOOL( ID_TBR_HELP,    FrmMain::OnManual    )
 
@@ -74,7 +77,7 @@ END_EVENT_TABLE( )
 //*****************************************************************************
 // Constructor.
 //
-// Argument List:
+// Argument List :
 //   poApp - A pointer to the class that created this object
 
 FrmMain::FrmMain( const wxApp * poApp ) :
@@ -164,6 +167,7 @@ void  FrmMain::InitMenuBar( void )
   poMenuSimu->Append( ID_MNU_CREATE,           wxT(" &Create    ") );
   poMenuSimu->Append( ID_MNU_RUN,              wxT(" &Run ") );
   poMenuSimu->Append( ID_MNU_STOP,             wxT(" &Stop ") );
+  poMenuSimu->Append( ID_MNU_EDIT,             wxT(" &Edit ... ") );
   poMenuSimu->Append( ID_MNU_PLOT,             wxT(" &Plot ... ") );
 
   poMenuSets->AppendRadioItem( ID_MNU_GNUCAP,  wxT("  &GNU-Cap ") );
@@ -195,7 +199,7 @@ void  FrmMain::InitMenuBar( void )
 
 void  FrmMain::InitToolBar( void )
 {
-  wxBitmap  * poPixMap[ 9 ];
+  wxBitmap  * poPixMap[ 10 ];
   wxToolBar * poToolBar;
 
   // Create the tool bar
@@ -209,8 +213,9 @@ void  FrmMain::InitToolBar( void )
   poPixMap[ 4 ] = new wxBitmap( sim_create_xpm );
   poPixMap[ 5 ] = new wxBitmap( sim_run_xpm );
   poPixMap[ 6 ] = new wxBitmap( sim_stop_xpm );
-  poPixMap[ 7 ] = new wxBitmap( sim_plot_xpm );
-  poPixMap[ 8 ] = new wxBitmap( help_xpm );
+  poPixMap[ 7 ] = new wxBitmap( sim_edit_xpm );
+  poPixMap[ 8 ] = new wxBitmap( sim_plot_xpm );
+  poPixMap[ 9 ] = new wxBitmap( help_xpm );
 
   // Add the tools to the toolbar
   poToolBar->AddTool( ID_TBR_OPEN,   wxT(""), *(poPixMap[ 0 ]),
@@ -229,17 +234,19 @@ void  FrmMain::InitToolBar( void )
   poToolBar->AddTool( ID_TBR_STOP,   wxT(""), *(poPixMap[ 6 ]),
                       wxT("Stop Simulation") );
   poToolBar->AddSeparator( );
-  poToolBar->AddTool( ID_TBR_PLOT,   wxT(""), *(poPixMap[ 7 ]),
+  poToolBar->AddTool( ID_TBR_EDIT,   wxT(""), *(poPixMap[ 7 ]),
+                      wxT("Edit Schematic/s") );
+  poToolBar->AddTool( ID_TBR_PLOT,   wxT(""), *(poPixMap[ 8 ]),
                       wxT("Plot Simulation Results") );
   poToolBar->AddSeparator( );
-  poToolBar->AddTool( ID_TBR_HELP,   wxT(""), *(poPixMap[ 8 ]),
+  poToolBar->AddTool( ID_TBR_HELP,   wxT(""), *(poPixMap[ 9 ]),
                       wxT("View Manual") );
 
   // Realize the toolbar
   poToolBar->Realize( );
 
   // Delete the bitmaps
-  for( int i1=0; i1<9; i1++ ) delete poPixMap[ i1 ];
+  for( int i1=0; i1<10; i1++ ) delete poPixMap[ i1 ];
 }
 
 //*****************************************************************************
@@ -300,7 +307,7 @@ void  FrmMain::InitSimrEng( void )
     m_oSim.bSetSimrType( eSIMR_GNUCAP );
     // Check the simulator item in the Options menu and the status bar message
     GetMenuBar( )->FindItem( FrmMain::ID_MNU_GNUCAP )->Check( );
-    SetStatusText( wxT(" Simulation Engine : GNU-Cap"), 2 );
+    SetStatusText( wxT(" Simulator : GNU-Cap"), 2 );
   }
   else
   {
@@ -310,7 +317,7 @@ void  FrmMain::InitSimrEng( void )
     m_oSim.bSetSimrType( eSIMR_NGSPICE );
     // Check the simulator item in the Options menu and the status bar message
     GetMenuBar( )->FindItem( FrmMain::ID_MNU_NGSPICE )->Check( );
-    SetStatusText( wxT(" Simulation Engine : NG-Spice"), 2 );
+    SetStatusText( wxT(" Simulator : NG-Spice"), 2 );
   }
 
   InitLogFiles( ); // Set the simulator process log file name
@@ -330,26 +337,29 @@ void  FrmMain::InitNbkTCtls( void )
 
 //*****************************************************************************
 // Initialize the status bar.
+//
 // Note : The first field in the status bar has a width of zero and is not used
 //        since the frame has the bad habit of writing text into it as the user
 //        moves the mouse over frame controls.
 
 void  FrmMain::InitStatBar( void )
 {
-  int  iaWidths[3];
+  int  iaWidths[ 4 ];
 
   // Create the status bar
-  CreateStatusBar( 3 );
+  CreateStatusBar( 4 );
 
   // Determine the status bar field widths
   iaWidths[ 0 ] = 3;   // Vanishingly thin
   iaWidths[ 1 ] = -1;  // Variable width
-  iaWidths[ 2 ] = 215; // Fixed width
-  SetStatusWidths( 3, iaWidths );
+  iaWidths[ 2 ] = 140; // Fixed width
+  iaWidths[ 3 ] = 120; // Fixed width
+  SetStatusWidths( 4, iaWidths );
 
   // Set status bar text
-  SetStatusText( wxT(" Welcome to GNU Spice GUI"), 1 );
-  SetStatusText( wxT(" Simulation Engine : None"), 2 );
+  SetStatusText( wxT(" Welcome to GNU Spice GUI"),                  1 );
+  SetStatusText( wxT(" Simulator : None"),                          2 );
+  SetStatusText( wxT(" Viewer : ")+m_oDlgPrefs.rosGetWaveViewer( ), 3 );
 }
 
 //*****************************************************************************
@@ -391,9 +401,6 @@ void  FrmMain::InitLogFiles( void )
 
   // Set the log file path for the simulation process object
   if( m_poPrcSimr != NULL ) m_poPrcSimr->bSetLogFile( os1 );
-
-  // Set the log file path for the gWave process object
-  m_oPrcGWave.bSetLogFile( os1 );
 }
 
 //*****************************************************************************
@@ -408,10 +415,11 @@ void  FrmMain::InitPosnSize( void )
   GetClientSize( &iw, &ih );
 
   // Get the position and size from the configuration object
-  ix = m_poConfig->Read( wxT("/Main/PosnX"), ix );
-  iy = m_poConfig->Read( wxT("/Main/PosnY"), iy );
-  iw = m_poConfig->Read( wxT("/Main/SizeW"), iw );
-  ih = m_poConfig->Read( wxT("/Main/SizeH"), ih );
+  m_poConfig->SetPath( wxT("/Main") );
+  ix = m_poConfig->Read( wxT("PosnX"), 1      );
+  iy = m_poConfig->Read( wxT("PosnY"), iy     );
+  iw = m_poConfig->Read( wxT("SizeW"), iw     );
+  ih = m_poConfig->Read( wxT("SizeH"), ih+100 );
 
   // Set the position and size
   Move( ix, iy );
@@ -424,10 +432,10 @@ void  FrmMain::InitPosnSize( void )
 void  FrmMain::DoLayout( void )
 {
   wxGridBagSizer * poSizer;
-  wxGBPosition  oGBPosn;
-  wxGBSpan      oGBSpan;
-  int  iFlags = wxALL | wxALIGN_CENTER | wxEXPAND;
-  int  iBorder = 3;
+  wxGBPosition     oGBPosn;
+  wxGBSpan         oGBSpan;
+  int              iFlags = wxALL | wxALIGN_CENTER | wxEXPAND;
+  int              iBorder = 3;
 
   if( GetSizer( ) == NULL )
   { // Create the sizer
@@ -489,14 +497,14 @@ void  FrmMain::DoLayout( void )
 //*****************************************************************************
 // Load information from the Simulation object.
 //
-// Argument List:
+// Argument List :
 //   bReload - Flag indicating if it is a load or reload operation
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  FrmMain::bLoadSim( bool bReload )
+bool  FrmMain::bSimLoad( bool bReload )
 {
   TextCtrl * poTxtCtl;
   uint       ui1;
@@ -526,22 +534,25 @@ bool  FrmMain::bLoadSim( bool bReload )
   poTxtCtl->bClear( );
   for( sz1=0; sz1<m_oSim.GetCount( ); sz1++ )
     poTxtCtl->bAppendLine( m_oSim.Item( sz1 ) );
-  poTxtCtl->SetInsertionPoint( 0 ); // Go to top of the netlist text control
+  poTxtCtl->SetInsertionPoint( 0 );  // Go to top of the netlist text control
 
   // Load the analysis notebook with simulation information
   if( ! bReload ) m_poNbkSimr->bLoad( m_oSim );
 
+  // Set the schematic file name/s in the schematic editor
+  m_oPrcGSchem.bSetSchems( m_oFileTsks.roasGetSchemFiles( ) );
+
   return( TRUE );
 }
 
 //*****************************************************************************
 // Reload information from the Simulation object.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  FrmMain::bReloadSim( void )
+bool  FrmMain::bSimReload( void )
 {
   wxArrayString  oasTstNodes;
   wxArrayString  oasTstCpnts;
@@ -566,7 +577,7 @@ bool  FrmMain::bReloadSim( void )
   m_oLbxNodes.Clear( );
   m_oLbxCpnts.Clear( );
 
-  bLoadSim( TRUE );  // Load the Simulation object
+  bSimLoad( TRUE );  // Load the Simulation object
 
   // Select nodes that where previously selected
   if( ! oasTstNodes.IsEmpty( ) )
@@ -597,11 +608,11 @@ bool  FrmMain::bReloadSim( void )
 //*****************************************************************************
 // Save information to the Simulation object.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  FrmMain::bSaveSim( void )
+bool  FrmMain::bSimSave( void )
 {
   wxArrayInt  oaiSelNodes, oaiSelCpnts;
   size_t      sz1;
@@ -652,14 +663,14 @@ bool  FrmMain::bSaveSim( void )
 //*****************************************************************************
 // Display a dialog box containing an error message.
 //
-// Argument List:
-//   rosTitle  - The dialogue box title
-//   rosMsg    - The error message
+// Argument List :
+//   rosTitle - The dialogue box title
+//   rosMsg   - The error message
 
 void  FrmMain::DlgErrMsg( const wxString & rosTitle, const wxString & rosMsg )
 {
   wxStringTokenizer  ostk1;
-  wxString  os1, os2, os3;
+  wxString           os1, os2, os3;
 
   // Tokenize the message into lines
   ostk1.SetString( rosMsg, wxT("\n\r"), wxTOKEN_STRTOK );
@@ -704,24 +715,25 @@ void  FrmMain::DlgErrMsg( const wxString & rosTitle, const wxString & rosMsg )
 // Check that the electronic circuit simulator engine is present and accounted
 // for, if not display an error message.
 //
-// Argument List:
-//   poPrcSimr - The utility object to be tested
+// Argument List :
+//   poPrcSimEng - The utility object to be tested
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  FrmMain::bIsOkSimEng( PrcSimrBase * poPrcSimr )
+bool  FrmMain::bIsOkSimEng( PrcBase * poPrcSimEng )
 {
-  wxString  osErrMsg;
+  wxString  os1;
 
   // Check that gnetlist exists and is accessible
-  if( ! poPrcSimr->bBinExists( ) )
+  if( ! poPrcSimEng->bBinExists( ) )
   {
-    osErrMsg << wxT("\nCan't find ") << poPrcSimr->rofnGetBinary( ).GetFullName( )
-             << wxT(" which is required to run electronic simulation.\n")
-             << wxT("There is no path to it or it has not been installed.\n\n");
-    DlgErrMsg( wxT("Configuration Fault"), osErrMsg );
+    os1 << wxT("\nCan't find ") << poPrcSimEng->rofnGetBinary( ).GetFullName( )
+        << wxT(" which is required to run electronic simulation.\n")
+        << wxT("There is no path to it or it has not been installed.\n\n");
+    DlgErrMsg( wxT("Configuration Fault"), os1 );
+
     return( FALSE );
   }
 
@@ -729,27 +741,28 @@ bool  FrmMain::bIsOkSimEng( PrcSimrBase * poPrcSimr )
 }
 
 //*****************************************************************************
-// Check that the results plotter utility is present and accounted for, if not
+// Check that the waveform viewer utility is present and accounted for, if not
 // display an error message.
 //
-// Argument List:
-//   poPrcGWave - The utility object to be tested
+// Argument List  :
+//   poPrcViewer - The utility object to be tested
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  FrmMain::bIsOkGWave( PrcGWave * poPrcGWave )
+bool  FrmMain::bIsOkViewer( PrcBase * poPrcViewer )
 {
   wxString  os1;
 
-  // Check that the plotter utility exists and is accessible
-  if( ! poPrcGWave->bBinExists( ) )
+  // Check that the waveform viewer utility exists and is accessible
+  if( ! poPrcViewer->bBinExists( ) )
   {
-    os1 << wxT("\nCan't find ") << poPrcGWave->rofnGetBinary( ).GetFullName( )
+    os1 << wxT("\nCan't find ") << poPrcViewer->rofnGetBinary( ).GetFullName( )
         << wxT(" which is required to plot simulation results.\n")
         << wxT("There is no path to it or it has not been installed.\n\n");
     DlgErrMsg( wxT("Configuration Fault"), os1 );
+
     return( FALSE );
   }
 
@@ -761,7 +774,7 @@ bool  FrmMain::bIsOkGWave( PrcGWave * poPrcGWave )
 
 bool  FrmMain::bClear( void )
 {
-  bool  bRtn=TRUE;
+  bool  bRtnValue = TRUE;
 
   // Clear all previously selected test points
   m_oLbxNodes.Clear( );
@@ -771,19 +784,24 @@ bool  FrmMain::bClear( void )
   m_oSim.bClear( );
 
   // Clear the simulation object and the analysis panels
-  if( ! m_poNbkSimr->bClear( ) )  bRtn = FALSE;
+  if( ! m_poNbkSimr->bClear( ) )      bRtnValue = FALSE;
 
   // Clear the text controls
-  if( ! m_oNbkTxtCtls.bClear( ) ) bRtn = FALSE;
+  if( ! m_oNbkTxtCtls.bClear( ) )     bRtnValue = FALSE;
   m_oNbkTxtCtls.Initialize( );
 
-  // Terminate any simulation processes
-  if( ! m_poPrcSimr->bKill( ) )   bRtn = FALSE;
+  // Terminate any simulation process
+  if( ! m_poPrcSimr->bKill( ) )       bRtnValue = FALSE;
 
-  // Terminate any viewer processes
-  if( ! m_oPrcGWave.bKill( ) )    bRtn = FALSE;
+  // Terminate any schematic editor process
+  if( ! m_oPrcGSchem.bKill( ) )       bRtnValue = FALSE;
 
-  return( bRtn );
+  // Terminate any waveform viewer process
+  if( m_poConfig->Read( wxT("/Viewer/Name") ) == wxT("GWave") )
+       { if( ! m_oPrcGWave.bKill( ) ) bRtnValue = FALSE; }
+  else { if( ! m_oPrcGaw  .bKill( ) ) bRtnValue = FALSE; }
+
+  return( bRtnValue );
 }
 
 //*****************************************************************************
@@ -793,7 +811,7 @@ bool  FrmMain::bClear( void )
 //*****************************************************************************
 // Open a circuit description file.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnOpen( wxCommandEvent & roEvtCmd )
@@ -814,7 +832,7 @@ void  FrmMain::OnOpen( wxCommandEvent & roEvtCmd )
     m_poPrcSimr->bParseSim( m_oSim );
 
     // Attempt to load the simulation information
-    if( bLoadSim( ) )
+    if( bSimLoad( ) )
          SetStatusText( wxT(" Net list file opened successfully"), 1 );
     else SetStatusText( wxT(" Error/s encountered opening a net list file"), 1 );
 
@@ -828,7 +846,7 @@ void  FrmMain::OnOpen( wxCommandEvent & roEvtCmd )
 // Import a schematic file using gnetlist to convert the schematic to a circuit
 // description.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnImport( wxCommandEvent & roEvtCmd )
@@ -837,7 +855,7 @@ void  FrmMain::OnImport( wxCommandEvent & roEvtCmd )
   if( m_oFileTsks.bImport( m_oSim ) )
   {
     // Attempt to load the simulation information
-    if( bLoadSim( ) )
+    if( bSimLoad( ) )
          SetStatusText( wxT(" Schematic file/s imported successfully"), 1 );
     else SetStatusText( wxT(" Error/s encountered importing schematic file/s"), 1 );
 
@@ -853,7 +871,7 @@ void  FrmMain::OnImport( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Reload the schematic or net list file.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnReload( wxCommandEvent & roEvtCmd )
@@ -862,7 +880,7 @@ void  FrmMain::OnReload( wxCommandEvent & roEvtCmd )
   if( m_oFileTsks.bReload( m_oSim ) )
   {
     // Attempt to load the simulation information
-    if( bReloadSim( ) )
+    if( bSimReload( ) )
          SetStatusText( wxT(" Netlist file reloaded successfully"), 1 );
     else SetStatusText( wxT(" Error/s encountered reloading the netlist file"), 1 );
 
@@ -875,7 +893,7 @@ void  FrmMain::OnReload( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Close the circuit description file.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnClose( wxCommandEvent & roEvtCmd )
@@ -889,7 +907,7 @@ void  FrmMain::OnClose( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Exit the application.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnAppExit( wxCommandEvent & roEvtCmd )
@@ -900,7 +918,7 @@ void  FrmMain::OnAppExit( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Create the simulation.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnSimCreate( wxCommandEvent & roEvtCmd )
@@ -914,7 +932,7 @@ void  FrmMain::OnSimCreate( wxCommandEvent & roEvtCmd )
 
   if( ! m_oSim.IsEmpty( ) )
   {
-    if( bSaveSim( ) )
+    if( bSimSave( ) )
     {
       // Print the simulation to the simulation text control
       m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_SIMULTN );
@@ -941,15 +959,15 @@ void  FrmMain::OnSimCreate( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Run the simulation.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnSimRun( wxCommandEvent & roEvtCmd )
 {
-  TextCtrl * poTxtCtl;
+  TextCtrl             * poTxtCtl;
   NbkTxtCtls::ePageType  ePage;
-  wxFileName  ofn1;
-  wxString  os1;
+  wxFileName             ofn1;
+  wxString               os1;
 
   m_osErrMsg.Empty( );
 
@@ -971,7 +989,7 @@ void  FrmMain::OnSimRun( wxCommandEvent & roEvtCmd )
   { // Save the simulation in the text control to file
     poTxtCtl->SaveFile( m_oSim.rofnGetSaveFile( ).GetFullPath( ) );
   }
-  else if( bSaveSim( ) )
+  else if( bSimSave( ) )
   { // Load the simulation on file into the simulation text control
     poTxtCtl->bLoadFile( m_oSim.rofnGetSaveFile( ).GetFullPath( ) );
     // poTxcSimn is saved immediately after loading to clear IsModified flag
@@ -994,7 +1012,7 @@ void  FrmMain::OnSimRun( wxCommandEvent & roEvtCmd )
   m_poPrcSimr->PrintCmd( *poTxtCtl ); // Print the simulator command
   if( ! m_poPrcSimr->bExec( ) )
   {
-    m_osErrMsg = m_poPrcSimr->psGetErrMsg( );
+    m_osErrMsg = m_poPrcSimr->rosGetErrMsg( );
     DlgErrMsg( wxT( "Run Simulation Error" ), m_osErrMsg );
     ::wxEndBusyCursor( );             // Change the cursor to the default
     return;
@@ -1011,7 +1029,7 @@ void  FrmMain::OnSimRun( wxCommandEvent & roEvtCmd )
   wxYield( );
   if( ! m_poPrcSimr->bFmtResults( ) )
   {
-    m_osErrMsg = m_poPrcSimr->psGetErrMsg( );
+    m_osErrMsg = m_poPrcSimr->rosGetErrMsg( );
     DlgErrMsg( wxT( "Run Simulation Error" ), m_osErrMsg );
     ::wxEndBusyCursor( );             // Change the cursor to the default
     return;
@@ -1041,7 +1059,7 @@ void  FrmMain::OnSimRun( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Stop the simulation.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnSimStop( wxCommandEvent & roEvtCmd )
@@ -1058,23 +1076,53 @@ void  FrmMain::OnSimStop( wxCommandEvent & roEvtCmd )
   }
 }
 
+//*****************************************************************************
+// Edit the schematic file.
+//
+// Argument List :
+//   roEvtCmd - The event to be processed
+
+void  FrmMain::OnEdit( wxCommandEvent & roEvtCmd )
+{
+  wxString   os1 = wxT("Schematic Editor Error");
+
+  // Check if the schematic editor process is already running
+  if( m_oPrcGSchem.bIsExec( ) )
+  {
+    DlgErrMsg( os1, wxT("The schematic editor process is already running.") );
+    return;
+  }
+
+  // Check if a schematic file is currently set
+  if( m_oPrcGSchem.rosGetSchems( ).IsEmpty( ) )
+  {
+    DlgErrMsg( os1, wxT("There is no schematic file to edit.") );
+    return;
+  }
+
+  // Execute the schematic editor process
+  if( ! m_oPrcGSchem.bExec( ) )
+    // Something went wrong, display an error message
+    DlgErrMsg( os1, m_oPrcGSchem.rosGetErrMsg( ) );
+}
+
 //*****************************************************************************
 // Plot the simulation results.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnPlot( wxCommandEvent & roEvtCmd )
 {
-  TextCtrl * poTxtCtl;
+  TextCtrl  * poTxtCtl;
   wxFileName  ofn1;
-  wxString  os1;
+  wxString    os1 = wxT("Plot Results Error");
+  wxString    os2;
 
-  // Check if the plotter process is already running
-  if( m_oPrcGWave.bIsExec( ) )
+  // Check if the waveform viewer process is already running
+  if( m_oPrcGaw.bIsExec( ) || m_oPrcGWave.bIsExec( ) )
   {
-    os1 = wxT("The gWave process is already running.");
-    DlgErrMsg( wxT( "Plot Results Error" ), os1 );
+    DlgErrMsg( os1, wxT("The waveform viewer process is already running.") );
     return;
   }
 
@@ -1082,59 +1130,68 @@ void  FrmMain::OnPlot( wxCommandEvent & roEvtCmd )
   ofn1 = m_oFileTsks.rosGetNetLstFile( );
   if( ofn1.GetFullPath( ).IsEmpty( ) )
   {
-    os1 = wxT("There is no schematic or net list file currently loaded.");
-    DlgErrMsg( wxT( "Plot Results Error" ), os1 );
+    DlgErrMsg( os1, wxT("There is no schematic or net list file currently loaded.") );
     return;
   }
 
   // Create the appropriate name for the results file
-  os1 = ofn1.GetName( );
+  os2 = ofn1.GetName( );
   switch( m_poNbkSimr->eGetSimrType( ) )
   {
     case eSIMR_GNUCAP :
       if( m_oNbkTxtCtls.eGetPage( ) == NbkTxtCtls::ePAGE_NGSPICE )
-           os1 << wxT(".ngspice");
-      else os1 << wxT(".gnucap");
+           os2 << wxT(".ngspice");
+      else os2 << wxT(".gnucap");
       break;
     case eSIMR_NGSPICE :
       if( m_oNbkTxtCtls.eGetPage( ) == NbkTxtCtls::ePAGE_GNUCAP )
-           os1 << wxT(".gnucap");
-      else os1 << wxT(".ngspice");
+           os2 << wxT(".gnucap");
+      else os2 << wxT(".ngspice");
       break;
     default: return;
   }
-  ofn1.SetName( os1 );
+  ofn1.SetName( os2 );
   ofn1.SetExt( m_poNbkSimr->rosGetPage( ) );
 
-  // Set the results file in the plotter process
+  // Set the results file in the waveform viewer process
   if( ! ofn1.FileExists( ) )
   {
-    os1.Empty( );
-    os1 << wxT("The simulation results file:\n\n") << ofn1.GetFullPath( )
+    os2.Empty( );
+    os2 << wxT("The simulation results file:\n\n") << ofn1.GetFullPath( )
         << wxT("\n\nhasn't yet been generated.");
-    DlgErrMsg( wxT( "Plot Results Error" ), os1 );
+    DlgErrMsg( os1, os2 );
     return;
   }
+  m_oPrcGaw  .bSetResults( ofn1.GetFullPath( ) );
   m_oPrcGWave.bSetResults( ofn1.GetFullPath( ) );
 
-  // Execute the plotter process
-  if( m_oPrcGWave.bExec( ) )
+  // Execute the waveform viewer process
+  if( m_poConfig->Read( wxT("/Viewer/Name") ) == wxT("GWave") )
   {
-    // Load the plotter output into the console text control
-    poTxtCtl = m_oNbkTxtCtls.poGetPage( NbkTxtCtls::ePAGE_CONSOLE );
-    m_oPrcGWave.Print( *poTxtCtl ); // Print the results
+    if( m_oPrcGWave.bExec( ) )
+    { // Load the waveform viewer output into the console text control
+      poTxtCtl = m_oNbkTxtCtls.poGetPage( NbkTxtCtls::ePAGE_CONSOLE );
+      m_oPrcGWave.Print( *poTxtCtl );
+    }
+    else // Something went wrong, display an error message
+      DlgErrMsg( os1, m_oPrcGWave.rosGetErrMsg( ) );
   }
   else
   {
-    os1 = m_oPrcGWave.psGetErrMsg( );
-    DlgErrMsg( wxT( "Plot Results Error" ), os1 );
+    if( m_oPrcGaw.bExec( ) )
+    { // Load the waveform viewer output into the console text control
+      poTxtCtl = m_oNbkTxtCtls.poGetPage( NbkTxtCtls::ePAGE_CONSOLE );
+      m_oPrcGaw.Print( *poTxtCtl );  // Print the results
+    }
+    else // Something went wrong, display an error message
+      DlgErrMsg( os1, m_oPrcGaw.rosGetErrMsg( ) );
   }
 }
 
 //*****************************************************************************
 // Select which simulator to use.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnSelSimr( wxCommandEvent & roEvtCmd )
@@ -1184,16 +1241,22 @@ void  FrmMain::OnSelSimr( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Show the application preferences dialog.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnPrefs( wxCommandEvent & roEvtCmd )
 {
+  wxString  os1;
+
   m_oDlgPrefs.CenterOnParent( );
   m_oDlgPrefs.ShowModal( );
 
   if( m_oDlgPrefs.GetReturnCode( ) == wxID_OK )
   {
+    // Set the waveform viewer
+    os1 = wxT(" Viewer : ") + m_oDlgPrefs.rosGetWaveViewer( );
+    SetStatusText( os1, 3 );
+
     // Set the text control maximum lines
     m_oNbkTxtCtls.bSetLinesMax( m_oDlgPrefs.iGetMaxLines( ) );
 
@@ -1205,7 +1268,7 @@ void  FrmMain::OnPrefs( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Display the gSpiceUI manual.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnManual( wxCommandEvent & roEvtCmd )
@@ -1216,7 +1279,7 @@ void  FrmMain::OnManual( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Display about message dialog.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnAbout( wxCommandEvent & roEvtCmd )
@@ -1228,7 +1291,7 @@ void  FrmMain::OnAbout( wxCommandEvent & roEvtCmd )
 // Change the cursor when a simulation is running and the mouse is over the
 // stop button.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - The event to be processed
 
 void  FrmMain::OnTbrEnter( wxCommandEvent & roEvtCmd )
@@ -1254,21 +1317,22 @@ void  FrmMain::OnTbrEnter( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Event handler for system close.
 //
-// Argument List:
+// Argument List :
 //   roEvtClose - The event to be processed
 
 void  FrmMain::OnSysExit( wxCloseEvent & roEvtClose )
 {
   wxString  os1;
-  int  ix, iy, iw, ih;
+  int       ix, iy, iw, ih;
 
   // Save the frame size and position
+  m_poConfig->SetPath( wxT("/Main") );
   GetClientSize( &iw, &ih );
   GetPosition( &ix, &iy );
-  m_poConfig->Write( wxT("/Main/PosnX"), (long) ix );
-  m_poConfig->Write( wxT("/Main/PosnY"), (long) iy );
-  m_poConfig->Write( wxT("/Main/SizeW"), (long) iw );
-  m_poConfig->Write( wxT("/Main/SizeH"), (long) ih );
+  m_poConfig->Write( wxT("PosnX"), (long) ix );
+  m_poConfig->Write( wxT("PosnY"), (long) iy );
+  m_poConfig->Write( wxT("SizeW"), (long) iw );
+  m_poConfig->Write( wxT("SizeH"), (long) ih );
   m_poConfig->Flush( );
 
   // Record the simulation engine
@@ -1281,6 +1345,11 @@ void  FrmMain::OnSysExit( wxCloseEvent & roEvtClose )
   os1 = m_poNbkSimr->rosGetPage( );
   m_poConfig->Write( wxT("Analysis"), os1.Upper( ) );
 
+  // Record the waveform veiwer
+  m_poConfig->SetPath( wxT("/Viewer") );
+  if( m_poConfig->Read( wxT("Name") ).IsEmpty( ) )
+    m_poConfig->Write( wxT("Name"), wxT("GWave") );
+
   bClear( );            // Kill any processes currently running
 
   m_oFileTsks.bExit( ); // Delete temporary files
