@@ -2,7 +2,7 @@
 //                                HelpTasks.cpp                               *
 //                               ---------------                              *
 //  Started     : 03/06/2005                                                  *
-//  Last Update : 08/10/2007                                                  *
+//  Last Update : 24/01/2008                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -146,10 +146,11 @@ void  HelpTasks::InitPosnSize( void )
   int  ix, iy, iw, ih;
 
   // Set the position and size from the configuration object
-  ix = m_poConfig->Read( wxT("/Help/PosnX"), ix );
-  iy = m_poConfig->Read( wxT("/Help/PosnY"), iy );
-  iw = m_poConfig->Read( wxT("/Help/SizeW"), iw );
-  ih = m_poConfig->Read( wxT("/Help/SizeH"), ih );
+  m_poConfig->SetPath( wxT("/Help") );
+  ix = m_poConfig->Read( wxT("PosnX"), 500 );
+  iy = m_poConfig->Read( wxT("PosnY"),   1 );
+  iw = m_poConfig->Read( wxT("SizeW"), 500 );
+  ih = m_poConfig->Read( wxT("SizeH"), 700 );
 
   if( ix>0 && iy>0 ) Move( ix, iy );
   if( iw>0 && ih>0 ) SetClientSize( iw, ih );
