@@ -2,7 +2,7 @@
 //                                Simulation.cpp                              *
 //                               ----------------                             *
 //  Started     : 23/09/2003                                                  *
-//  Last Update : 18/09/2007                                                  *
+//  Last Update : 29/02/2008                                                  *
 //  Copyright   : (C) 2003 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -104,15 +104,17 @@ bool  Simulation::bExtractSimCmds( void )
 
     os1.MakeUpper( );
 
-    if(      os1.StartsWith( wxT(".OPT") ) ) m_osOPTIONS = os1;
-    else if( os1.StartsWith( wxT(".GEN") ) ) ;
-    else if( os1.StartsWith( wxT(".IC")  ) ) ;
-    else if( os1.StartsWith( wxT(".OP")  ) ) ;
-    else if( os1.StartsWith( wxT(".DC")  ) ) ;
-    else if( os1.StartsWith( wxT(".AC")  ) ) ;
-    else if( os1.StartsWith( wxT(".TR")  ) ) ;
-    else if( os1.StartsWith( wxT(".FO")  ) ) ;
-    else if( os1.StartsWith( wxT(".PR")  ) ) ;
+    if(      os1.StartsWith( wxT(".OPT")   ) ) m_osOPTIONS = os1;
+    else if( os1.StartsWith( wxT(".GEN")   ) ) ;
+    else if( os1.StartsWith( wxT(".IC")    ) ) ;
+    else if( os1.StartsWith( wxT(".OP")    ) ) ;
+    else if( os1.StartsWith( wxT(".DC")    ) ) ;
+    else if( os1.StartsWith( wxT(".AC")    ) ) ;
+    else if( os1.StartsWith( wxT(".TR")    ) ) ;
+    else if( os1.StartsWith( wxT(".FO")    ) ) ;
+    else if( os1.StartsWith( wxT(".PR")    ) ) ;
+    else if( os1.StartsWith( wxT(".PARAM") ) ) ;
+    else if( os1.StartsWith( wxT(".SET")   ) ) ;
     else continue;
 
     os1 << wxT('\n');
@@ -168,6 +170,13 @@ bool  Simulation::bClear( void )
   bool  bRtnValue=TRUE;
   uint  ui1;
 
+  // Clear the simulation engine and analysis type specifiers
+  if( ! bSetSimrType( eSIMR_NONE ) )            bRtnValue = FALSE;
+  if( ! bSetAnaType( eANA_NONE ) )              bRtnValue = FALSE;
+
+  // Clear the sweep parameter array
+  for( ui1=0; ui1<eSWP_SIZE; ui1++ ) m_fSwp[ ui1 ] = -FLT_MAX;
+
   // Clear all parameter specifiers
   for( ui1=ePAR_FST; ui1<=ePAR_LST; ui1++ )
     if( ! bSetOutPar( (eParType) ui1, FALSE ) ) bRtnValue = FALSE;
@@ -176,15 +185,8 @@ bool  Simulation::bClear( void )
   for( ui1=eCPX_FST; ui1<=eCPX_LST; ui1++ )
     if( ! bSetOutCpx( (eCpxType) ui1, FALSE ) ) bRtnValue = FALSE;
 
-  // Clear the simulation engine and analysis type specifiers
-  if( ! bSetSimrType( eSIMR_NONE ) )            bRtnValue = FALSE;
-  if( ! bSetAnaType( eANA_NONE ) )              bRtnValue = FALSE;
-
-  // Clear the sweep parameter array
-  for( ui1=0; ui1<eSWP_SIZE; ui1++ ) m_fSwp[ ui1 ] = -FLT_MAX;
-
   // Clear temperature
-  m_fTempC = 27.0;
+  m_fTempC = -FLT_MAX;
 
   // Clear everything else
   m_oasTstNodes  .Empty( );
@@ -262,7 +264,8 @@ bool  Simulation::bLoadFile( const wxString & rosFName )
         break;
       case eSIMR_NGSPICE:
         poCmdOPTIONS = new CmdNgSpiceOPT;
-        poCmdOPTIONS->bSetCmd( m_osOPTIONS );
+        (wxString) *poCmdOPTIONS = m_osOPTIONS;
+        poCmdOPTIONS->bParse( );
         m_fTempC = ((CmdNgSpiceOPT *) poCmdOPTIONS)->m_fTEMP;
         delete ((CmdNgSpiceOPT *) poCmdOPTIONS);
         break;
@@ -385,48 +388,6 @@ bool  Simulation::bSetAnaType( eAnaType eAna )
   return( TRUE );
 }
 
-//*****************************************************************************
-// Enable or disable the derivation of an analysis parameter.
-//
-// Arguments:
-//   ePar   - The parameter to set
-//   bState - Indicate whether the parameter is to be derived or not
-//            (TRUE - derive parameter, FALSE - don't derive parameter)
-//
-// Return Values:
-//   TRUE  - Success
-//   FALSE - Failure
-
-bool  Simulation::bSetOutPar( eParType ePar, bool bState )
-{
-  if( ePar<ePAR_FST || ePar>ePAR_LST ) return( FALSE );
-
-  m_bPar[ ePar ] = bState;
-
-  return( TRUE );
-}
-
-//*****************************************************************************
-// Enable or disable the derivation of a part of a complex analysis parameter.
-//
-// Arguments:
-//   eCpx   - The complex part to set
-//   bState - Indicate whether the parameter is to be derived or not
-//            (TRUE - derive parameter, FALSE - don't derive parameter)
-//
-// Return Values:
-//   TRUE  - Success
-//   FALSE - Failure
-
-bool  Simulation::bSetOutCpx( eCpxType eCpx, bool bState )
-{
-  if( eCpx<eCPX_FST || eCpx>eCPX_LST ) return( FALSE );
-
-  m_bCpx[ eCpx ] = bState;
-
-  return( TRUE );
-}
-
 //*****************************************************************************
 // Set the sweep start point.
 //
@@ -503,6 +464,48 @@ bool  Simulation::bSetSwpScale( int iScale )
   return( TRUE );
 }
 
+//*****************************************************************************
+// Enable or disable the derivation of an analysis parameter.
+//
+// Arguments:
+//   ePar   - The parameter to set
+//   bState - Indicate whether the parameter is to be derived or not
+//            (TRUE - derive parameter, FALSE - don't derive parameter)
+//
+// Return Values:
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  Simulation::bSetOutPar( eParType ePar, bool bState )
+{
+  if( ePar<ePAR_FST || ePar>ePAR_LST ) return( FALSE );
+
+  m_bPar[ ePar ] = bState;
+
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Enable or disable the derivation of a part of a complex analysis parameter.
+//
+// Arguments:
+//   eCpx   - The complex part to set
+//   bState - Indicate whether the parameter is to be derived or not
+//            (TRUE - derive parameter, FALSE - don't derive parameter)
+//
+// Return Values:
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  Simulation::bSetOutCpx( eCpxType eCpx, bool bState )
+{
+  if( eCpx<eCPX_FST || eCpx>eCPX_LST ) return( FALSE );
+
+  m_bCpx[ eCpx ] = bState;
+
+  return( TRUE );
+}
+
 //*****************************************************************************
 // Set the analysis temperature in degrees Celcius.
 //
@@ -724,3 +727,78 @@ void  Simulation::ClrSigSrc( void )
 }
 
 //*****************************************************************************
+// Print the object attributes.
+//
+// Argument List :
+//   psPrefix - A prefix to every line displayed (usually just spaces)
+
+void  Simulation::Print( const char * psPrefix )
+{
+  int     i1;
+  size_t  sz1;
+
+  cout << psPrefix << "m_eSimrType        : ";
+  switch( m_eSimrType )
+  {
+    case eSIMR_GNUCAP  : cout << "eSIMR_GNUCAP";  break;
+    case eSIMR_NGSPICE : cout << "eSIMR_NGSPICE"; break;
+    case eSIMR_NONE    : cout << "eSIMR_NONE";    break;
+  }
+  cout << '\n';
+
+  cout << psPrefix << "m_eAnaType         : ";
+  switch( m_eAnaType )
+  {
+    case eANA_OP   : cout << "eANA_OP";   break;  // Operating point analysis
+    case eANA_DC   : cout << "eANA_DC";   break;  // DC analysis
+    case eANA_AC   : cout << "eANA_AC";   break;  // AC analysis
+    case eANA_TR   : cout << "eANA_TR";   break;  // Transient analysis
+    case eANA_FO   : cout << "eANA_FO";   break;  // Fourier analysis
+    case eANA_DI   : cout << "eANA_DI";   break;  // Distortion analysis
+    case eANA_NO   : cout << "eANA_NO";   break;  // Noise analysis
+    case eANA_PZ   : cout << "eANA_PZ";   break;  // Pole-zero analysis
+    case eANA_SE   : cout << "eANA_SE";   break;  // Sensitivity analysis
+    case eANA_TF   : cout << "eANA_TF";   break;  // Transfer function analysis
+    case eANA_NONE : cout << "eANA_NONE"; break;  // Analysis type not set
+  }
+  cout << '\n';
+
+  cout << psPrefix << "m_fSwp[ n ]        :";
+  for( i1=(int)eSWP_START; i1<=(int)eSWP_START; i1++ )
+    cout << ' ' << m_fSwp[ i1 ];
+  cout << '\n';
+
+  cout << psPrefix << "m_bPar[ n ]        :";
+  for( i1=(int)ePAR_FST; i1<=(int)ePAR_LST; i1++ )
+    cout << ( m_bPar[ i1 ] ? " TRUE " : " FALSE" );
+  cout << '\n';
+
+  cout << psPrefix << "m_bCpx[ n ]        :";
+  for( i1=(int)eCPX_FST; i1<=(int)eCPX_LST; i1++ )
+    cout << ( m_bCpx[ i1 ] ? " TRUE " : " FALSE" );
+  cout << '\n';
+
+  cout << psPrefix << "m_fTempC           : " << m_fTempC << '\n';
+
+  cout << psPrefix << "m_osaTstNodes[ n ] :";
+  for( sz1=0; sz1<m_oasTstNodes.GetCount( ); sz1++ )
+    cout << ' ' << m_oasTstNodes[ sz1 ].mb_str( );
+  cout << '\n';
+
+  cout << psPrefix << "m_osaTstCpnts[ n ] :";
+  for( sz1=0; sz1<m_oasTstCpnts.GetCount( ); sz1++ )
+    cout << ' ' << m_oasTstCpnts[ sz1 ].mb_str( );
+  cout << '\n';
+
+  cout << psPrefix << "m_osaSimCmds[ n ]  :";
+  for( sz1=0; sz1<m_oasSimCmds.GetCount( ); sz1++ )
+    cout << ' ' << m_oasSimCmds[ sz1 ].mb_str( );
+  cout << '\n';
+
+  cout << psPrefix << "m_osSigSrc[ 0 ]    : " << m_osSigSrc[ 0 ].mb_str( ) << '\n'
+       << psPrefix << "m_osSigSrc[ 1 ]    : " << m_osSigSrc[ 1 ].mb_str( ) << '\n';
+
+  cout << psPrefix << "m_osOPTIONS        : " << m_osOPTIONS.mb_str( ) << '\n';
+}
+
+//*****************************************************************************
