@@ -2,7 +2,7 @@
 //                              CmdNgSpiceAC.cpp                              *
 //                             ------------------                             *
 //  Started     : 11/10/2007                                                  *
-//  Last Update : 16/10/2007                                                  *
+//  Last Update : 21/02/2008                                                  *
 //  Copyright   : (C) 2007 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -36,11 +36,11 @@ CmdNgSpiceAC::~CmdNgSpiceAC( )
 //*****************************************************************************
 // Parse the command string.
 //
-// Eg.s : .AC LIN 30 1.00K 300.00K
-//        .AC DEC 30 1.00K 300.00K
-//        .AC OCT 30 1.00K 300.00K
+// Eg.s : .AC LIN 50 1.00K 300.00K
+//        .AC DEC 20 1.00K 300.00K
+//        .AC OCT 10 1.00K 300.00K
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -51,14 +51,15 @@ bool  CmdNgSpiceAC::bParse( void )
   double             df1;
   long               li1;
 
+  // Clear the object attributes
+  os1 = *this;
+  bClear( );
+  *this = os1;
+
   // Tokenize the command string
   ostk1.SetString( *this );
   if( ostk1.CountTokens( ) != 5 ) return( FALSE );
 
-  // Clear object attributes but keep the command string
-  bClear( );
-  (wxString &) *this = ostk1.GetString( );
-
   // Check command type
   os1 = ostk1.GetNextToken( ).Left( 3 ).Upper( );
   if( os1 != wxT(".AC") )         return( FALSE );
@@ -71,22 +72,22 @@ bool  CmdNgSpiceAC::bParse( void )
   if(      os1 == wxT("LIN") ) m_eScale = eSCALE_LIN;
   else if( os1 == wxT("DEC") ) m_eScale = eSCALE_DEC;
   else if( os1 == wxT("OCT") ) m_eScale = eSCALE_OCT;
-  else m_bIsOk = FALSE;
+  else                            m_bIsOk = FALSE;
 
   // Extract the step count
   os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToInt( os1, &li1 ) ) m_iStep  = (int) li1;
-  else m_bIsOk = FALSE;
+  if( ConvertType::bStrToInt( os1, &li1 ) ) m_fStep  = (float) li1;
+  else                            m_bIsOk = FALSE;
 
   // Extract the start frequency
   os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) ) m_fStart = (float) df1;
-  else m_bIsOk = FALSE;
+  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStart = (float) df1;
+  else                            m_bIsOk = FALSE;
 
   // Extract the stop frequency
   os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) ) m_fStop  = (float) df1;
-  else m_bIsOk = FALSE;
+  if( ConvertType::bStrToFlt( os1, &df1 ) ) m_fStop  = (float) df1;
+  else                            m_bIsOk = FALSE;
 
   return( m_bIsOk );
 }
@@ -94,60 +95,141 @@ bool  CmdNgSpiceAC::bParse( void )
 //*****************************************************************************
 // Format the command string.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  CmdNgSpiceAC::bFormat( void )
 {
-  wxString  os1, os2;
+  wxString  osCmd, os1;
 
   m_bIsOk = FALSE;
 
-  os1 = wxT(".DC");
+  osCmd = wxT(".AC");
 
   switch( m_eScale )
   {
-    case eSCALE_LIN : os1 << wxT(" LIN"); break;
-    case eSCALE_DEC : os1 << wxT(" DEC"); break;
-    case eSCALE_OCT : os1 << wxT(" OCT"); break;
-    default :                                              return( FALSE );
+    case eSCALE_LIN : osCmd << wxT(" LIN"); break;
+    case eSCALE_DEC : osCmd << wxT(" DEC"); break;
+    case eSCALE_OCT : osCmd << wxT(" OCT"); break;
+    default         :                                         return( FALSE );
   }
 
-  os1 << wxT(' ') << m_iStep;
+  osCmd << wxT(' ') << (int) lroundf( m_fStep );
 
-  if( ! ConvertType::bFltToStr( (double) m_fStart, os2 ) ) return( FALSE );
-  os1 << wxT(' ') << os2;
+  if( ! ConvertType::bFltToStrEng( (double) m_fStart, os1 ) ) return( FALSE );
+  osCmd << wxT(' ') << os1;
 
-  if( ! ConvertType::bFltToStr( (double) m_fStop,  os2 ) ) return( FALSE );
-  os1 << wxT(' ') << os2;
+  if( ! ConvertType::bFltToStrEng( (double) m_fStop,  os1 ) ) return( FALSE );
+  osCmd << wxT(' ') << os1;
+
+  *this = osCmd;
 
   m_bIsOk = TRUE;
-  (wxString) *this = os1;
 
-  return( TRUE );
+  return( m_bIsOk );
 }
 
 //*****************************************************************************
 // Clear the object attributes.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  CmdNgSpiceAC::bClear( void )
 {
-  bool  bRtnValue;
-
-  bRtnValue = CmdBase::bClear( );
+  CmdBase::bClear( );
 
   m_fStart = -FLT_MAX;
   m_fStop  = -FLT_MAX;
-  m_iStep  =  INT_MIN;
+  m_fStep  = -FLT_MIN;
 
   m_eScale = eSCALE_NONE;
 
-  return( bRtnValue );
+  return( TRUE );
 }
 
 //*****************************************************************************
+//                                                                            *
+//                                 Test Utility                               *
+//                                                                            *
+//*****************************************************************************
+
+#ifdef TEST_UTIL
+
+// System include files
+
+
+// Application includes
+
+
+// Function prototypes
+
+void  Usage( char * psAppName );
+
+//*****************************************************************************
+
+int  main( int argc, char * argv[ ] )
+{
+  wxString  osCmd;
+  wxString  os1;
+
+  // Validate the argument count passed to the application
+  if( argc > 2 )           { Usage( argv[ 0 ] ); exit( EXIT_FAILURE ); }
+
+  // Process the command line arguments
+  os1 = wxConvLibc.cMB2WC( argv[ 1 ] );
+  if( argc > 1 )
+  {
+    if( os1 == wxT("-h") ) { Usage( argv[ 0 ] ); exit( EXIT_SUCCESS ); }
+    else                   { Usage( argv[ 0 ] ); exit( EXIT_FAILURE ); }
+  }
+
+  // Display the utility banner
+  cout << "\n  Class CmdNgSpiceAC Test Utility"
+       << "\n     Version 1.00 (01/02/2008)\n";
+
+  // Create a GNU-CAP AC command object
+  CmdNgSpiceAC  oCmd_AC;
+
+  // Use the following command example to check the formatter and the parser :
+  osCmd = wxT(".AC DEC 30 1.00K 300.00K");
+
+  // Set things up for a formatter test
+  oCmd_AC.bClear( );
+  oCmd_AC.m_fStart = 1.0E3;
+  oCmd_AC.m_fStop  = 300.0E3;
+  oCmd_AC.m_fStep  = 30;
+  oCmd_AC.m_eScale = eSCALE_DEC;
+  cout << "\nRun Formatter    : " << ( oCmd_AC.bFormat( ) ? "OK" : "FAULT" );
+  cout << "\nTest Cmd Format  : " << ( oCmd_AC == osCmd   ? "OK" : "FAULT" );
+  cout << "\nExample Command  : " << osCmd  .mb_str( );
+  cout << "\noCmd_AC Contents : " << oCmd_AC.mb_str( ) << '\n';
+
+  // Set things up for a parser test
+  oCmd_AC.bClear( );
+  oCmd_AC = osCmd;
+  cout << "\nRun Parser       : " << ( oCmd_AC.bParse( ) ? "OK" : "FAULT" );
+  oCmd_AC.bFormat( );
+  cout << "\nTest Cmd Format  : " << ( oCmd_AC == osCmd  ? "OK" : "FAULT" );
+  cout << "\nExample Command  : " << osCmd  .mb_str( );
+  cout << "\noCmd_AC Contents : " << oCmd_AC.mb_str( ) << '\n';
+
+  cout << '\n';
+
+  exit( EXIT_SUCCESS );
+}
+
+//*****************************************************************************
+
+void  Usage( char * psAppName )
+{
+  cout << "\nUsage   : " << psAppName << " [-OPTIONS]"
+       << "\nOptions :"
+       << "\n  -h : Print usage (this message)\n";
+}
+
+#endif // TEST_UTIL
+
+//*****************************************************************************
