@@ -4,7 +4,7 @@
 //  Description : This class contains values associated with the NG-SPICE     *
 //                OPTIONS command. It inherits from the class CmdBase.        *
 //  Started     : 23/08/2006                                                  *
-//  Last Update : 04/10/2007                                                  *
+//  Last Update : 11/12/2007                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -60,14 +60,9 @@
 
 //*****************************************************************************
 
-class CmdNgSpiceOPT : public CmdBase
+struct CmdNgSpiceOPT : public CmdBase
 {
-  protected:
-
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
-
-  public:
+  public :
 
     // Options used by NG-Spice and GNU-Cap
     float     m_fABSTOL;  // Abs. current error tolerance
@@ -96,6 +91,12 @@ class CmdNgSpiceOPT : public CmdBase
     virtual  ~CmdNgSpiceOPT( );
 
     bool  bClear( void );
+
+    virtual  bool  bParse ( void );
+    virtual  bool  bFormat( void );
+
+    wxString & operator = ( const wxString & ros )
+                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
 };
 
 //*****************************************************************************
