@@ -4,7 +4,7 @@
 //  Description : This class contains values associated with the NG-Spice     *
 //                TRANSIENT command. It inherits from the class CmdBase.      *
 //  Started     : 15/10/2007                                                  *
-//  Last Update : 15/10/2007                                                  *
+//  Last Update : 15/01/2008                                                  *
 //  Copyright   : (C) 2007 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -18,8 +18,8 @@
 //                                                                            *
 //*****************************************************************************
 
-#ifndef CMDNGSPICEDC_HPP
-#define CMDNGSPICEDC_HPP
+#ifndef CMDNGSPICETR_HPP
+#define CMDNGSPICETR_HPP
 
 // System Includes
 
@@ -41,14 +41,9 @@
 
 //*****************************************************************************
 
-class CmdNgSpiceTR : public CmdBase
+struct CmdNgSpiceTR : public CmdBase
 {
-  protected:
-
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
-
-  public:
+  public :
 
     float       m_fStart;    // The sweep start value
     float       m_fStop;     // The sweep stop  value
@@ -59,6 +54,12 @@ class CmdNgSpiceTR : public CmdBase
     virtual  ~CmdNgSpiceTR( );
 
     bool  bClear( void );
+
+    virtual  bool  bParse ( void );
+    virtual  bool  bFormat( void );
+
+    wxString & operator = ( const wxString & ros )
+                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
 };
 
 //*****************************************************************************
