@@ -2,7 +2,7 @@
 //                              DlgNgSpiceOPT.cpp                             *
 //                             -------------------                            *
 //  Started     : 03/03/2006                                                  *
-//  Last Update : 09/10/2007                                                  *
+//  Last Update : 12/12/2007                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -456,7 +456,9 @@ bool  DlgNgSpiceOPT::bClear( void )
 
 bool  DlgNgSpiceOPT::bSetCmd( const wxString & rosCmd )
 {
-  if( CmdBase::bSetCmd( rosCmd ) ) return( FALSE );
+  CmdNgSpiceOPT::bClear( );
+  *((wxString *) this) = rosCmd;
+  if( ! CmdNgSpiceOPT::bParse( ) ) return( FALSE );
 
   SetValues( );
 
