@@ -2,7 +2,7 @@
 //                               PnlNgSpiceAC.cpp                             *
 //                              ------------------                            *
 //  Started     : 04/08/2004                                                  *
-//  Last Update : 05/10/2007                                                  *
+//  Last Update : 29/02/2008                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -147,10 +147,10 @@ bool  PnlNgSpiceAC::bClear( void )
 
   // Clear the base class
   if( ! PnlAnaBase::bClear( ) )       bRtnValue = FALSE;
+
+  // Set the sweep parameters to their defaults
   m_oPnlStart.bSetValue( (float) 1.0 );
   m_oPnlStep .bSetValue( (float) 10.0 );
-
-  // Set the default sweep units
   m_oPnlStart.bSetUnits( wxT("kHz") );
   m_oPnlStop .bSetUnits( wxT("kHz") );
 
@@ -199,6 +199,11 @@ bool  PnlNgSpiceAC::bLoad( Simulation & roSim )
   m_oCbxReal .SetValue( roSim.bGetOutCpx( eCPX_REAL  ) );
   m_oCbxImag .SetValue( roSim.bGetOutCpx( eCPX_IMAG  ) );
   m_oCbxMagDb.SetValue( roSim.bGetOutCpx( eCPX_MAGDB ) );
+  if( !m_oCbxPhase.GetValue() && !m_oCbxReal.GetValue() && !m_oCbxImag.GetValue() )
+  {
+    m_oCbxMag  .SetValue( TRUE );
+    m_oCbxMagDb.SetValue( TRUE );
+  }
 
   // Perform any base class load tasks
   if( ! PnlAnaBase::bLoad( roSim ) )           bRtnValue = FALSE;
