@@ -2,7 +2,7 @@
 //                               PrcGnuCap.cpp                                *
 //                              ---------------                               *
 //  Started     : 01/09/2003                                                  *
-//  Last Update : 08/10/2007                                                  *
+//  Last Update : 07/01/2008                                                  *
 //  Copyright   : (C) 2003 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -127,6 +127,7 @@ bool  PrcGnuCap::bParseCmdOP( wxString & rosCmd, Simulation & roSim )
 
 //*****************************************************************************
 // Parse a DC command and put the data in a simulation object.
+//
 // Eg.s: .DC Vin 0.00 TE 27.00 BASIC
 //       .DC Vin 0.00 100.00m BY 10.00m TE 27.00 BASIC
 //       .DC Vin 0.00 100.00m TI 1.01 TE 27.00 BASIC
@@ -991,7 +992,7 @@ bool  PrcGnuCap::bFmtResults( void )
   // Format the simulation results
   if( roGetResultsFile( ).GetFullName( ).Right( 3 ) == wxT(".fo") )
        bRtnValue = bFmtResultsFO( );
-  else bRtnValue = bFmtResultsAny( );
+  else bRtnValue = bFmtGeneric( );
 
   // Need last line to end with a '\n' or text controls will not load it
   if( m_oFileResults.GetLastLine( ).Last( ) != wxT('\n') )
@@ -1011,7 +1012,7 @@ bool  PrcGnuCap::bFmtResults( void )
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  PrcGnuCap::bFmtResultsAny( void )
+bool  PrcGnuCap::bFmtGeneric( void )
 {
   wxString  os1, os2;
   size_t    sz1, sz2;
