@@ -2,7 +2,7 @@
 //                               PrcNgSpice.cpp                               *
 //                              ----------------                              *
 //  Started     : 07/05/2004                                                  *
-//  Last Update : 24/10/2007                                                  *
+//  Last Update : 09/01/2008                                                  *
 //  Copyright   : (C) 2004 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -40,11 +40,11 @@ PrcNgSpice::~PrcNgSpice( )
 //*****************************************************************************
 // Parse a OP command and put the data in a simulation object.
 //
-// Argument List:
+// Argument List :
 //   rosCmd - The command line to be parsed
 //   roSim  - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -58,11 +58,11 @@ bool  PrcNgSpice::bParseCmdOP( wxString & rosCmd, Simulation & roSim )
 //*****************************************************************************
 // Parse a IC command and put the data in a simulation object.
 //
-// Argument List:
+// Argument List :
 //   rosCmd - The command line to be parsed
 //   roSim  - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -76,152 +76,101 @@ bool  PrcNgSpice::bParseCmdIC( wxString & rosCmd, Simulation & roSim )
 //*****************************************************************************
 // Parse a DC command and put the data in a simulation object.
 //
-// Argument List:
+// Argument List :
 //   rosCmd - The command line to be parsed
 //   roSim  - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  PrcNgSpice::bParseCmdDC( wxString & rosCmd, Simulation & roSim )
 {
   bool          bRtnValue=TRUE;
-  CmdNgSpiceDC  oCmd_DC;
+  CmdNgSpiceDC  tCmd_DC;
   wxString      os1;
 
   // Parse the DC command
-  if( ! oCmd_DC.bSetCmd( rosCmd ) )              return( FALSE );
+  tCmd_DC = rosCmd;
+  if( ! tCmd_DC.bParse( ) )                      return( FALSE );
 
-  // Extract the sweep type: source or temperature
-  if( oCmd_DC.m_osSource == wxT("TEMP") )
+  // Set the sweep type: source or temperature
+  if( tCmd_DC.m_osSource == wxT("TEMP") )
     roSim.bSetSwpScale( 1 );
   else
   {
-    os1 = roSim.rosGetCpnt( oCmd_DC.m_osSource );
+    os1 = roSim.rosGetCpnt( tCmd_DC.m_osSource );
     if( !os1.IsEmpty( ) && roSim.bSetSigSrc( os1 ) )
          roSim.bSetSwpScale( 0 );
     else                                         bRtnValue = FALSE;
   }
 
-  // Extract the sweep start, stop and step values
-  if( ! roSim.bSetSwpStart( oCmd_DC.m_fStart ) ) bRtnValue = FALSE;
-  if( ! roSim.bSetSwpStop ( oCmd_DC.m_fStop  ) ) bRtnValue = FALSE;
-  if( ! roSim.bSetSwpStep ( oCmd_DC.m_fStep  ) ) bRtnValue = FALSE;
+  // Set the sweep start, stop and step values
+  if( ! roSim.bSetSwpStart( tCmd_DC.m_fStart ) ) bRtnValue = FALSE;
+  if( ! roSim.bSetSwpStop ( tCmd_DC.m_fStop  ) ) bRtnValue = FALSE;
+  if( ! roSim.bSetSwpStep ( tCmd_DC.m_fStep  ) ) bRtnValue = FALSE;
 
   return( bRtnValue );
 }
 
 //*****************************************************************************
 // Parse a AC command and put the data in a simulation object.
-// Eg.s: .AC LIN 30 1.00K 300.00K
-//       .AC DEC 30 1.00K 300.00K
-//       .AC OCT 30 1.00K 300.00K
 //
-// Argument List:
+// Argument List :
 //   rosCmd - The command line to be parsed
 //   roSim  - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  PrcNgSpice::bParseCmdAC( wxString & rosCmd, Simulation & roSim )
 {
-  wxStringTokenizer  ostk1;
-  wxString  os1;
-  bool      bRtnValue=TRUE;
-  double    df1;
-  long      li1;
+  bool          bRtnValue=TRUE;
+  CmdNgSpiceAC  tCmd_AC;
 
-  // Basic argument checks
-  ostk1.SetString( rosCmd.Upper( ) );
-  if( ostk1.CountTokens( ) != 5 )             return( FALSE );
+  // Parse the AC command
+  tCmd_AC = rosCmd;
+  if( ! tCmd_AC.bParse( ) )                            return( FALSE );
 
-  // Check command type
-  os1 = ostk1.GetNextToken( );
-  if( os1 != wxT(".AC") )                     return( FALSE );
+  // Extract the sweep start, stop and step values
+  if( ! roSim.bSetSwpStart( tCmd_AC.m_fStart ) )       bRtnValue = FALSE;
+  if( ! roSim.bSetSwpStop ( tCmd_AC.m_fStop  ) )       bRtnValue = FALSE;
+  if( ! roSim.bSetSwpStep ( tCmd_AC.m_fStep  ) )       bRtnValue = FALSE;
 
-  // Extract the sweep type: linear or log
-  os1 = ostk1.GetNextToken( );
-  if(      os1 == wxT("LIN") ) roSim.bSetSwpScale( 0 );
-  else if( os1 == wxT("DEC") ) roSim.bSetSwpScale( 2 );
-  else if( os1 == wxT("OCT") ) roSim.bSetSwpScale( 3 );
-  else                                        bRtnValue = FALSE;
-
-  // Extract the step count
-  os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToInt( os1, &li1 ) ) bRtnValue = FALSE;
-  if( ! roSim.bSetSwpStep( (float) li1 ) )    bRtnValue = FALSE;
-
-  // Extract the start frequency
-  os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) ) bRtnValue = FALSE;
-  if( ! roSim.bSetSwpStart( (float) df1 ) )   bRtnValue = FALSE;
-
-  // Extract the stop frequency
-  os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) ) bRtnValue = FALSE;
-  if( ! roSim.bSetSwpStop( (float) df1 ) )    bRtnValue = FALSE;
+  // Set the sweep scale type
+  if( ! roSim.bSetSwpScale( (int) tCmd_AC.m_eScale ) ) bRtnValue = FALSE;
 
   return( bRtnValue );
 }
 
 //*****************************************************************************
 // Parse a TRANSIENT command and put the data in a simulation object.
-// Eg.s: .TRAN 10.00m 100.00m 0.00 10.00m
-//       .TRAN 10.00m 100.00m 0.00 10.00m UIC
 //
-// Argument List:
+// Argument List :
 //   rosCmd - The command line to be parsed
 //   roSim  - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  PrcNgSpice::bParseCmdTR( wxString & rosCmd, Simulation & roSim )
 {
-  wxStringTokenizer  ostk1;
-  wxString  os1;
-  bool      bRtnValue=TRUE;
-  double    df1;
-  int       i1;
+  bool          bRtnValue=TRUE;
+  CmdNgSpiceTR  tCmd_TR;
 
-  // Basic argument checks
-  ostk1.SetString( rosCmd );
-  i1 = ostk1.CountTokens( );
-  if( i1!=5 && i1!=6 )                        return( FALSE );
+  // Parse the TR command
+  tCmd_TR = rosCmd;
+  if( ! tCmd_TR.bParse( ) )                            return( FALSE );
 
-  // Check command type
-  os1 = ostk1.GetNextToken( );
-  if( os1.Upper( ) != wxT(".TRAN") )          return( FALSE );
+  // Extract the sweep start, stop and step values
+  if( ! roSim.bSetSwpStart( tCmd_TR.m_fStart ) )       bRtnValue = FALSE;
+  if( ! roSim.bSetSwpStop ( tCmd_TR.m_fStop  ) )       bRtnValue = FALSE;
+  if( ! roSim.bSetSwpStep ( tCmd_TR.m_fStep  ) )       bRtnValue = FALSE;
 
-  // Extract the step size (must be present)
-  os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) ) bRtnValue = FALSE;
-  if( ! roSim.bSetSwpStep( (float) df1 ) )    bRtnValue = FALSE;
-
-  // Extract the stop time (must be present)
-  os1 = ostk1.GetNextToken( );
-  if( ! ConvertType::bStrToFlt( os1, &df1 ) ) bRtnValue = FALSE;
-  if( ! roSim.bSetSwpStop( (float) df1 ) )    bRtnValue = FALSE;
-
-  // Extract the start time (may not be specified)
-  os1.Empty( );
-  if( ostk1.HasMoreTokens( ) )
-  {
-    os1 = ostk1.GetNextToken( );
-    if( ! ConvertType::bStrToFlt( os1, &df1 ) ) df1 = 0.0;
-    else os1.Empty( );
-    if( ! roSim.bSetSwpStart( (float) df1 ) ) bRtnValue = FALSE;
-  }
-
-  // Extract the initial conditions
-  while( ostk1.HasMoreTokens( ) ) os1 = ostk1.GetNextToken( );
-  if( os1.Upper( ) == wxT("UIC") ) i1 = (int) eINITC_UICS;
-  else                             i1 = (int) eINITC_WARM;
-  if( ! roSim.bSetSwpScale( i1 ) )            bRtnValue = FALSE;
+  // Set the initial conditions
+  if( ! roSim.bSetSwpScale( (int) tCmd_TR.m_eInitC ) ) bRtnValue = FALSE;
 
   return( bRtnValue );
 }
@@ -229,96 +178,54 @@ bool  PrcNgSpice::bParseCmdTR( wxString & rosCmd, Simulation & roSim )
 //*****************************************************************************
 // Parse a PRINT command and put the data in a simulation object.
 //
-// Argument List:
+// Argument List :
 //   rosCmd - The command line to be parsed
 //   roSim  - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  PrcNgSpice::bParseCmdPR( wxString & rosCmd, Simulation & roSim )
 {
-  wxStringTokenizer  ostk1;
-  wxString           os1;
-  bool               bRtnValue=TRUE;
-  size_t             sz1, sz2;
+  bool          bRtnValue=TRUE;
+  CmdNgSpicePR  tCmd_PR;
+  wxString      os1;
+  size_t        sz1;
 
-  // Basic argument checks
-  ostk1.SetString( rosCmd.Upper( ) );
-  if( ostk1.CountTokens( ) < 3 )      return( FALSE );
-
-  // Check command type
-  os1 = ostk1.GetNextToken( ).Left( 6 );
-  if( os1 != wxT(".PRINT") ) return( FALSE );
+  // Parse the PR command
+  tCmd_PR = rosCmd;
+  if( ! tCmd_PR.bParse( ) ) return( FALSE );
 
   // Extract the analysis type
-  os1 = ostk1.GetNextToken( );
-  if(      os1 == wxT("DC")   ) roSim.bSetAnaType( eANA_DC );
-  else if( os1 == wxT("AC")   ) roSim.bSetAnaType( eANA_AC );
-  else if( os1 == wxT("TRAN") ) roSim.bSetAnaType( eANA_TR );
-  else return( FALSE );
+  roSim.bSetAnaType( tCmd_PR.m_eAnaType );
 
-  // Extract the parameters to derive, any complex parts and the test component
-  // and/or test node labels
-  while( ostk1.HasMoreTokens( ) )
+  // Extract the parameter specifier
+  for( sz1=(size_t)ePAR_FST; sz1<=(size_t)ePAR_LST; sz1++ )
+    roSim.bSetOutPar( (eParType) sz1, tCmd_PR.m_bParms[ sz1 ] );
+
+  // Extract the complex part if the analysis type is AC
+  if( roSim.eGetAnaType( ) == eANA_AC )
   {
-    // Extract the next field
-    os1 = ostk1.GetNextToken( );
-    if( os1.Length( ) < 4 ) { bRtnValue = FALSE; continue; }
+    for( sz1=(size_t)eCPX_FST; sz1<=(size_t)eCPX_LST; sz1++ )
+      roSim.bSetOutCpx( (eCpxType) sz1, tCmd_PR.m_bCpxPrts[ sz1 ] );
+  }
 
-    // Standardize the parameter format; there are 3 possible formats eg. V(n),
-    // V(n,m) or 0-V(n). The latter is reformatted to : V(0,n).
-    if( os1.StartsWith( wxT("0-") ) )
-    {
-      sz1 = os1.Index( wxT('(') );
-      sz2 = os1.Index( wxT(')') );
-      if( (int)sz1!=wxNOT_FOUND && (int)sz2!=wxNOT_FOUND && sz2>(sz1+1) )
-        os1 = os1.Mid( 2, sz1-1 ) + wxT("0,") + os1.Mid( sz1+1 );
-    }
+  // Extract the test nodes
+  for( sz1=0; sz1<tCmd_PR.m_osaNodes.GetCount( ); sz1++ )
+    if( ! roSim.bAddTstNode( tCmd_PR.m_osaNodes[ sz1 ] ) )
+      bRtnValue = FALSE;
 
-    // Extract the parameter specifier
-    switch( os1.GetChar( 0 ) )
-    {
-      case wxT('V') : roSim.bSetOutPar( ePAR_VLT, TRUE ); break;
-      case wxT('I') : roSim.bSetOutPar( ePAR_CUR, TRUE ); break;
-      case wxT('P') : roSim.bSetOutPar( ePAR_PWR, TRUE ); break;
-      case wxT('R') : roSim.bSetOutPar( ePAR_RES, TRUE ); break;
-      default :       bRtnValue = FALSE; break;
-    }
+  // Extract test components
+  for( sz1=0; sz1<tCmd_PR.m_osaCpnts.GetCount( ); sz1++ )
+  {
+    os1 = tCmd_PR.m_osaCpnts[ sz1 ];
 
-    // Extract the complex part if the analysis type is AC
-    if( roSim.eGetAnaType( ) == eANA_AC )
-    {
-      switch( os1.GetChar( 1 ) )
-      {
-        case wxT('M') : roSim.bSetOutCpx( eCPX_MAG,   TRUE ); break;
-        case wxT('P') : roSim.bSetOutCpx( eCPX_PHASE, TRUE ); break;
-        case wxT('R') : roSim.bSetOutCpx( eCPX_REAL,  TRUE ); break;
-        case wxT('I') : roSim.bSetOutCpx( eCPX_IMAG,  TRUE ); break;
-        case wxT('D') :
-          if( os1.Mid( 1, 2 ).Upper( ) == wxT("DB") )
-          {
-            roSim.bSetOutCpx( eCPX_MAG,   TRUE );
-            roSim.bSetOutCpx( eCPX_MAGDB, TRUE );
-            break;
-          }
-        default: bRtnValue = FALSE; break;
-      }
-    }
+    if( bMatchCpnt( roSim, os1 ) )
+      if( ! roSim.bAddTstCpnt( os1 ) )
+        continue;
 
-    // Extract the node label/s, there are 2 possible formats eg. V(n) or
-    // V(n,m). The first denotes a node and the second a component.
-    sz1 = os1.Index( wxT('(') );
-    sz2 = os1.Index( wxT(')') );
-    if( (int)sz1==wxNOT_FOUND || (int)sz2==wxNOT_FOUND || (sz1+1)>=sz2 )
-       { bRtnValue = FALSE; continue; }
-    os1 = os1.Mid( sz1+1, sz2-sz1-1 );
-    if( roSim.roasGetNodeLbls( ).Index( os1 ) != wxNOT_FOUND )
-      roSim.bAddTstNode( os1 );
-    else if( bMatchCpnt( roSim, os1 ) )
-      roSim.bAddTstCpnt( os1 );
-    else bRtnValue = FALSE;
+    bRtnValue = FALSE;
   }
 
   return( bRtnValue );
@@ -326,17 +233,17 @@ bool  PrcNgSpice::bParseCmdPR( wxString & rosCmd, Simulation & roSim )
 
 //*****************************************************************************
 // Match a component to a set of node labels. Component voltages cannot be
-// specified using the component label in the Ng-Spice print statement. The two
+// specified using the component label in the NG-Spice print statement. The two
 // node labels connected to the component must be specified. When parsing the
 // print statement the component label must be derived from the node labels.
 // This may not work where components are connected in parallel. The nodes are
 // specified in the form "<Node1>,<Node2>" eg. "1,2".
 //
-// Argument List:
+// Argument List :
 //   rosToNodes - The nodes to match, also used to return the component label
 //
-// Return Values:
-//   TRUE  - Success (A component with the specified nodes was found)
+// Return Values :
+//   TRUE  - Success (a component with the specified nodes was found)
 //   FALSE - Failure
 
 bool  PrcNgSpice::bMatchCpnt( Simulation & roSim, wxString & rosToNodes )
@@ -376,162 +283,114 @@ bool  PrcNgSpice::bMatchCpnt( Simulation & roSim, wxString & rosToNodes )
 //*****************************************************************************
 // Create the simulator command sequence for a DC analysis.
 //
-// Argument List:
+// Argument List :
 //   roSim - Simulation object
 
-void  PrcNgSpice::MakeCmdDC( Simulation & roSim )
+void  PrcNgSpice::MakeCmdsDC( Simulation & roSim )
 {
-  wxString  osCmdWIDTH;
-  wxString  osCmdPR;
-  wxString  osCmdDC;
-  wxString  osPar, os1;
-  uint      uiPar;
+  CmdNgSpicePR  tCmd_PR;
+  CmdNgSpiceDC  tCmd_DC;
+  wxString      osCmdWIDTH;
+  int           i1;
 
   // Clear the field list
   m_osFieldLst.Empty( );
 
   // Create the DC command
-  osCmdDC = wxT(".DC ");
+  tCmd_DC.m_fStart = roSim.fGetSwpStart( );
+  tCmd_DC.m_fStop  = roSim.fGetSwpStop ( );
+  tCmd_DC.m_fStep  = roSim.fGetSwpStep ( );
   if( roSim.iGetSwpScale( ) == 0 )
-       osCmdDC << roSim.rosGetSigSrc( ).BeforeFirst( wxT(' ') ) << wxT(' ');
-  else osCmdDC << wxT("TEMP ");
-  osCmdDC << roSim.rosGetSwpStart( ) << wxT(' ')
-          << roSim.rosGetSwpStop ( ) << wxT(' ')
-          << roSim.rosGetSwpStep ( );
+       tCmd_DC.m_osSource = roSim.rosGetSigSrc( ).BeforeFirst( wxT(' ') );
+  else tCmd_DC.m_osSource = wxT("TEMP");
+  tCmd_DC.bFormat( );
 
   // Create the PRINT command
-  osCmdPR = wxT(".PRINT DC");
-  for( uiPar=ePAR_FST; uiPar<=ePAR_LST; uiPar++ )
-  {
-    if( ! roSim.bGetOutPar( (eParType) uiPar ) ) continue;
-
-    switch( uiPar )
-    {
-      case ePAR_VLT : osPar = wxT("V("); break;
-      case ePAR_CUR : osPar = wxT("I("); break;
-      case ePAR_PWR : osPar = wxT("P("); break;
-      case ePAR_RES : osPar = wxT("R("); break;
-      default :       continue;
-    }
-
-    // Add any components and/or nodes to derivation list for this parameter
-    os1 = rosMakeArgsPR( roSim, osPar );
-    if( ! os1.IsEmpty( ) ) osCmdPR << os1;
-  }
+  tCmd_PR.m_eAnaType = eANA_DC;
+  tCmd_PR.m_osaNodes = roSim.roasGetTstNodes( );
+  tCmd_PR.m_osaCpnts = roSim.roasGetTstCpnts( );
+  for( i1=(int) ePAR_FST; i1<=(int) ePAR_LST; i1++ )
+    tCmd_PR.m_bParms  [ i1 ] = roSim.bGetOutPar( (eParType) i1 );
+  for( i1=(int) eCPX_FST; i1<=(int) eCPX_LST; i1++ )
+    tCmd_PR.m_bCpxPrts[ i1 ] = roSim.bGetOutCpx( (eCpxType) i1 );
+  tCmd_PR.bFormat( );
+  MakeFieldLst( tCmd_PR, roSim );
 
   // Create the WIDTH command
-  osCmdWIDTH = rosMakeCmdWIDTH( osCmdPR );
+  osCmdWIDTH = rosMakeCmdWIDTH( tCmd_PR );
 
   // Add simulation commands to Simulation object
   roSim.bAddSimCmd( osCmdWIDTH );
-  roSim.bAddSimCmd( osCmdPR );
-  roSim.bAddSimCmd( osCmdDC );
+  roSim.bAddSimCmd( tCmd_PR );
+  roSim.bAddSimCmd( tCmd_DC );
 }
 
 //*****************************************************************************
 // Create the simulator command sequence for a AC analysis.
 //
-// Argument List:
+// Argument List :
 //   roSim - Simulation object
 
-void  PrcNgSpice::MakeCmdAC( Simulation & roSim )
+void  PrcNgSpice::MakeCmdsAC( Simulation & roSim )
 {
-  wxString  osCmdWIDTH;
-  wxString  osCmdPR;
-  wxString  osCmdOP;
-  wxString  osCmdAC;
-  wxString  osPar, osCpx, os1;
-  uint      uiPar, uiCpx;
+  CmdNgSpicePR  tCmd_PR;
+  CmdNgSpiceAC  tCmd_AC;
+  wxString      osCmdWIDTH;
+  wxString      osCmdOP;
+  int           i1;
 
   // Clear the field list
   m_osFieldLst.Empty( );
 
   // Create the AC command
-  osCmdAC = wxT(".AC ");
-  switch( roSim.iGetSwpScale( ) )
-  {
-    case 0 : osCmdAC << wxT("LIN "); break;
-    case 2 : osCmdAC << wxT("DEC "); break;
-    case 3 : osCmdAC << wxT("OCT "); break;
-  }
-  osCmdAC << ( (int) roSim.fGetSwpStep( ) ) << wxT(' ')
-          << roSim.rosGetSwpStart( ) << wxT(' ')
-          << roSim.rosGetSwpStop( );
+  tCmd_AC.m_fStart = roSim.fGetSwpStart( );
+  tCmd_AC.m_fStop  = roSim.fGetSwpStop( );
+  tCmd_AC.m_fStep  = roSim.fGetSwpStep( );
+  tCmd_AC.m_eScale = (eScaleType) roSim.iGetSwpScale( );
+  tCmd_AC.bFormat( );
 
   // Create the PRINT command
-  osCmdPR = wxT(".PRINT AC");
-  for( uiPar=ePAR_FST; uiPar<=ePAR_LST; uiPar++ )
-  {
-    if( ! roSim.bGetOutPar( (eParType) uiPar ) ) continue;
-
-    // Add the parameter prefix
-    switch( uiPar )
-    {
-      case ePAR_VLT : osPar = wxT('V'); break;
-      case ePAR_CUR : osPar = wxT('I'); break;
-      case ePAR_PWR : osPar = wxT('P'); break;
-      case ePAR_RES : osPar = wxT('R'); break;
-      default: continue;
-    }
-
-    // Add the complex part prefix
-    for( uiCpx=eCPX_FST; uiCpx<=eCPX_LST; uiCpx++ )
-    {
-      if( ! roSim.bGetOutCpx( (eCpxType) uiCpx ) ) continue;
-
-      osCpx = osPar;
-
-      switch( uiCpx )
-      {
-        case eCPX_MAG :
-          if( ! roSim.bGetOutCpx( eCPX_MAGDB ) ) osCpx << wxT('M');
-          else                                   osCpx << wxT("DB");
-          break;
-        case eCPX_PHASE : osCpx << wxT('P'); break;
-        case eCPX_REAL  : osCpx << wxT('R'); break;
-        case eCPX_IMAG  : osCpx << wxT('I'); break;
-        default :         continue;
-      }
-      osCpx << wxT('(');
-
-      // Add any components and/or nodes to derivation list for this parameter
-      os1 = rosMakeArgsPR( roSim, osCpx );
-      if( ! os1.IsEmpty( ) ) osCmdPR << os1;
-    }
-  }
+  tCmd_PR.m_eAnaType = eANA_AC;
+  tCmd_PR.m_osaNodes = roSim.roasGetTstNodes( );
+  tCmd_PR.m_osaCpnts = roSim.roasGetTstCpnts( );
+  for( i1=(int) ePAR_FST; i1<=(int) ePAR_LST; i1++ )
+    tCmd_PR.m_bParms  [ i1 ] = roSim.bGetOutPar( (eParType) i1 );
+  for( i1=(int) eCPX_FST; i1<=(int) eCPX_LST; i1++ )
+    tCmd_PR.m_bCpxPrts[ i1 ] = roSim.bGetOutCpx( (eCpxType) i1 );
+  tCmd_PR.bFormat( );
+  MakeFieldLst( tCmd_PR, roSim );
 
   // Create the WIDTH command
-  osCmdWIDTH = rosMakeCmdWIDTH( osCmdPR );
+  osCmdWIDTH = rosMakeCmdWIDTH( tCmd_PR );
 
   // Add simulation commands to Simulation object
   roSim.bAddSimCmd( osCmdWIDTH );
-  roSim.bAddSimCmd( osCmdPR );
+  roSim.bAddSimCmd( tCmd_PR );
   roSim.bAddSimCmd( osCmdOP );
-  roSim.bAddSimCmd( osCmdAC );
+  roSim.bAddSimCmd( tCmd_AC );
 }
 
 //*****************************************************************************
 // Create the simulator command sequence for a transient analysis.
 //
-// Argument List:
+// Argument List :
 //   roSim - Simulation object
 
-void  PrcNgSpice::MakeCmdTR( Simulation & roSim )
+void  PrcNgSpice::MakeCmdsTR( Simulation & roSim )
 {
-  wxString  osCmdIC;
-  wxString  osCmdWIDTH;
-  wxString  osCmdPR;
-  wxString  osCmdTR;
-  wxString  osPar, os1;
-  uint      uiPar, ui1;
-  size_t    sz1;
+  CmdNgSpicePR  tCmd_PR;
+  CmdNgSpiceTR  tCmd_TR;
+  wxString      osCmdIC;
+  wxString      osCmdWIDTH;
+  int           i1;
+  size_t        sz1;
 
   // Clear the field list
   m_osFieldLst.Empty( );
 
   // Create initial conditions command
-  ui1 = (uint) roSim.iGetSwpScale( );
-  if( ui1==eINITC_COLD || ui1==eINITC_UICS )
+  i1 = roSim.iGetSwpScale( );
+  if( i1==eINITC_COLD || i1==eINITC_UICS )
   {
     const wxArrayString & roas1 = roSim.roasGetNodeLbls( );
     if( roas1.GetCount( ) > 0 )
@@ -543,52 +402,86 @@ void  PrcNgSpice::MakeCmdTR( Simulation & roSim )
   }
 
   // Create the TR command
-  osCmdTR << wxT(".TRAN ")
-          << roSim.rosGetSwpStep( ) << wxT(' ')
-          << roSim.rosGetSwpStop( ) << wxT(' ')
-          << roSim.rosGetSwpStart( ) << wxT(' ')
-          << roSim.rosGetSwpStep( );  // TMAX calculation increment
-  if( roSim.iGetSwpScale( ) == eINITC_UICS )
-    osCmdTR << wxT(" UIC");
+  tCmd_TR.m_fStart = roSim.fGetSwpStart( );
+  tCmd_TR.m_fStop  = roSim.fGetSwpStop( );
+  tCmd_TR.m_fStep  = roSim.fGetSwpStep( );
+  tCmd_TR.m_eInitC = (eInitCType) roSim.iGetSwpScale( );
+  tCmd_TR.bFormat( );
 
   // Create the PRINT commands
-  osCmdPR << wxT(".PRINT TRAN");
-  for( uiPar=ePAR_FST; uiPar<=ePAR_LST; uiPar++ )
-  {
-    if( ! roSim.bGetOutPar( (eParType) uiPar ) ) continue;
-
-    switch( uiPar )
-    {
-      case ePAR_VLT : osPar = wxT("V("); break;
-      case ePAR_CUR : osPar = wxT("I("); break;
-      case ePAR_PWR : osPar = wxT("P("); break;
-      case ePAR_RES : osPar = wxT("R("); break;
-      default :       continue;
-    }
-
-    // Add any components and/or nodes to derivation list for this parameter
-    os1 = rosMakeArgsPR( roSim, osPar );
-    if( ! os1.IsEmpty( ) ) osCmdPR << os1;
-  }
+  tCmd_PR.m_eAnaType = eANA_TR;
+  tCmd_PR.m_osaNodes = roSim.roasGetTstNodes( );
+  tCmd_PR.m_osaCpnts = roSim.roasGetTstCpnts( );
+  for( i1=(int) ePAR_FST; i1<=(int) ePAR_LST; i1++ )
+    tCmd_PR.m_bParms  [ i1 ] = roSim.bGetOutPar( (eParType) i1 );
+  for( i1=(int) eCPX_FST; i1<=(int) eCPX_LST; i1++ )
+    tCmd_PR.m_bCpxPrts[ i1 ] = roSim.bGetOutCpx( (eCpxType) i1 );
+  tCmd_PR.bFormat( );
+  MakeFieldLst( tCmd_PR, roSim );
 
   // Create the WIDTH command
-  osCmdWIDTH = rosMakeCmdWIDTH( osCmdPR );
+  osCmdWIDTH = rosMakeCmdWIDTH( tCmd_PR );
 
   // Add simulation commands to Simulation object
   roSim.bAddSimCmd( osCmdIC );
   roSim.bAddSimCmd( osCmdWIDTH );
-  roSim.bAddSimCmd( osCmdPR );
-  roSim.bAddSimCmd( osCmdTR );
+  roSim.bAddSimCmd( tCmd_PR );
+  roSim.bAddSimCmd( tCmd_TR );
+}
+
+//*****************************************************************************
+// Convert a list of component labels to the corresponding list of node pairs.
+//
+// Argument List:
+//   rtCmd_PR - A PRINT command structure
+//   roSim    - A Simulation object
+
+void  PrcNgSpice::MakeFieldLst( CmdNgSpicePR & rtCmd_PR, Simulation & roSim )
+{
+  m_osFieldLst = rtCmd_PR;
+  m_osFieldLst = m_osFieldLst.AfterFirst( wxT(' ') );
+  m_osFieldLst = m_osFieldLst.AfterFirst( wxT(' ') );
+
+  Convert2Nodes( rtCmd_PR.m_osaCpnts, roSim );
+
+  rtCmd_PR.bFormat( );
+}
+
+//*****************************************************************************
+// Convert a list of component labels to the corresponding list of node pairs.
+//
+// Argument List:
+//   roasCpnts - A list of component labels
+//   roSim     - A Simulation object
+
+void  PrcNgSpice::Convert2Nodes( wxArrayString & roasCpnts, Simulation & roSim )
+{
+  Component  oCpnt;
+  wxString   os1;
+  size_t     sz1;
+
+  for( sz1=0; sz1<roasCpnts.GetCount( ); sz1++ )
+  {
+    os1 = roasCpnts.Item( sz1 );
+    os1 = roSim.rosGetCpnt( os1.c_str( ) );
+    if( os1.IsEmpty( ) )                         continue;
+    if( ! oCpnt.bSetDefn( os1.c_str( ) ) )       continue;
+    if( oCpnt.roasGetNodes( ).GetCount( ) != 2 ) continue;
+    os1.Empty( );
+    os1 << oCpnt.roasGetNodes( ).Item( 0 ) << wxT(',')
+        << oCpnt.roasGetNodes( ).Item( 1 );
+    roasCpnts.Item( sz1 ) = os1;
+  }
 }
 
 //*****************************************************************************
 // Generate the simulator commands to be executed based on the simulation
 // specifications and the NetList description.
 //
-// Arguments:
+// Argument List :
 //   roSim - The net list and simulation specification
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -596,9 +489,9 @@ bool  PrcNgSpice::bMakeCmds( Simulation & roSim )
 {
   switch( roSim.eGetAnaType( ) )
   {
-    case eANA_DC : MakeCmdDC( roSim ); break;
-    case eANA_AC : MakeCmdAC( roSim ); break;
-    case eANA_TR : MakeCmdTR( roSim ); break;
+    case eANA_DC : MakeCmdsDC( roSim ); break;
+    case eANA_AC : MakeCmdsAC( roSim ); break;
+    case eANA_TR : MakeCmdsTR( roSim ); break;
     default :      return( FALSE );
   }
 
@@ -606,76 +499,16 @@ bool  PrcNgSpice::bMakeCmds( Simulation & roSim )
 }
 
 //*****************************************************************************
-// Create a list of arguments for the Spice PRINT command based on the test
-// components and test nodes specified in a Simulation object. A prefix may be
-// specified which is prepended to each argument in the list.
+// Create a WIDTH command based on a PRINT command.
+// By default raw output from NG-Spice uses an 80 column output width which
+// allows about two dependant variables to be displayed. To display more
+// information a .WIDTH statement must be added to increase the number columns
+// in the output.
 //
-// Argument List:
-//   roSim     - The Simulation object
-//   rosPrefix - The prefix to be prepended to each argument
-//
-// Return Values:
-//   Success - A list of correctly formatted arguments
-//   Failure - An empty string
-
-wxString & PrcNgSpice::rosMakeArgsPR( Simulation & roSim, wxString & rosPrefix )
-{
-  static  wxString  osArgs;
-  Component  oCpnt;
-  wxString   os1;
-  wxChar     oc1;
-  size_t     sz1;
-
-  osArgs.Empty( );
-
-  // Add any components to derivation list for this parameter
-  for( sz1=0; sz1<roSim.roasGetTstCpnts( ).GetCount( ); sz1++ )
-  {
-    os1 = roSim.roasGetTstCpnts( ).Item( sz1 );
-    m_osFieldLst << rosPrefix << os1 << wxT(") ");
-    os1 = roSim.rosGetCpnt( os1.c_str( ) );
-    if( os1.IsEmpty( ) )                   continue;
-    if( ! oCpnt.bSetDefn( os1.c_str( ) ) ) continue;
-    const wxArrayString & roas2 = oCpnt.roasGetNodes( );
-    if( roas2.GetCount( ) != 2 )           continue;
-    osArgs << wxT(' ');
-    if( roas2.Item( 0 ).IsSameAs( wxT('0') ) )
-         osArgs << wxT("0-") << rosPrefix << roas2.Item( 1 ) << wxT(")");
-    else osArgs << rosPrefix << roas2.Item( 0 ) << wxT(',') << roas2.Item( 1 )
-                << wxT(')');
-  }
-
-  // Add any nodes to derivation list for voltage only
-  for( oc1=0, sz1=0; sz1<rosPrefix.Length( ); sz1++ )
-  {
-    oc1 = rosPrefix.GetChar( sz1 );
-    if( ! wxIsspace( oc1 ) ) break;
-  }
-  if( oc1==wxT('v') || oc1==wxT('V') )
-  {
-    for( sz1=0; sz1<roSim.roasGetTstNodes( ).GetCount( ); sz1++ )
-    {
-      os1.Empty( );
-      os1 << wxT(' ') << rosPrefix << roSim.roasGetTstNodes( ).Item( sz1 )
-          << wxT(')');
-      osArgs << os1;
-      m_osFieldLst << os1 << wxT(' ');
-    }
-  }
-
-  return( osArgs );
-}
-
-//*****************************************************************************
-// Create a width command based on a PRINT command.
-// By default raw output from NG-Spice uses an 80 column output width, allows
-// about two dependant variables to be displayed. To display more information
-// a .WIDTH statement must be added setting the number columns in the output.
-//
-// Argument List:
+// Argument List :
 //   rosCmdPR - The Print command
 //
-// Return Values:
+// Return Values :
 //   Success - A .WIDTH command
 //   Failure - An empty string
 
@@ -711,7 +544,7 @@ wxString & PrcNgSpice::rosMakeCmdWIDTH( wxString & rosCmdPR )
 // header line at the top containing parameter names followed by the columns of
 // data.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -736,7 +569,7 @@ bool  PrcNgSpice::bFmtResults( void )
   }
 
   // Format the simulation results
-  bRtnValue = bFmtResultsAny( );
+  bRtnValue = bFmtGeneric( );
 
   // Need last line to end with a '\n' or text controls will not load it
   if( m_oFileResults.GetLastLine( ).Last( ) != wxT('\n') )
@@ -752,17 +585,17 @@ bool  PrcNgSpice::bFmtResults( void )
 // This function is a generic results file formatter which works in most
 // circumstance.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  PrcNgSpice::bFmtResultsAny( void )
+bool  PrcNgSpice::bFmtGeneric( void )
 {
   wxString  os1;
   size_t    sz1, sz2;
 
   // This function requires the result file to have been opened
-  if( ! m_oFileResults.IsOpened( ) )               return( FALSE );
+  if( ! m_oFileResults.IsOpened( ) ) return( FALSE );
 
   // Find the beginning of the data area (ie. the 1st line starting with "Index")
   for( sz1=0; sz1<m_oFileResults.GetLineCount( ); sz1++ )
@@ -778,8 +611,8 @@ bool  PrcNgSpice::bFmtResultsAny( void )
 
   // Delete everything before the data area
   sz2 = sz1;
-  for( sz1=0; sz1<sz2; sz1++ )          m_oFileResults.RemoveLine( 0 );
-  if( m_oFileResults.GetLineCount( ) > 0 )  m_oFileResults.RemoveLine( 1 );
+  for( sz1=0; sz1<sz2; sz1++ )             m_oFileResults.RemoveLine( 0 );
+  if( m_oFileResults.GetLineCount( ) > 0 ) m_oFileResults.RemoveLine( 1 );
 
   // Format the column header line
   bFmtColumnHdr( );
@@ -804,7 +637,7 @@ bool  PrcNgSpice::bFmtResultsAny( void )
 //*****************************************************************************
 // Format the column header in the results file.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -824,7 +657,7 @@ bool  PrcNgSpice::bFmtColumnHdr( void )
   // Dispose of the first field (ie. "Index")
   ostk1.GetNextToken( );
 
-  // Extract the operator field and replace the Ng-Spice field identifiers
+  // Extract the operator field and replace the NG-Spice field identifiers
   os1 << ostk1.GetNextToken( ) << wxT(' ') << m_osFieldLst;
   ostk1.SetString( os1 );
 
@@ -853,7 +686,7 @@ bool  PrcNgSpice::bFmtColumnHdr( void )
 //*****************************************************************************
 // Format a data lines in the results file.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -913,12 +746,14 @@ bool  PrcNgSpice::bFmtDataLines( void )
 // pertinent for AC analysis). It involves removing the discontinuity at 360
 // degree in the data.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  PrcNgSpice::bFmtPhaseData( void )
 {
+  // ??? (02/02/2006) Not yet implemented
+
   return( TRUE );
 }
 
@@ -926,10 +761,10 @@ bool  PrcNgSpice::bFmtPhaseData( void )
 // Parse the simulation commands strings found in a Simulation object and load
 // the values back into the Simulation object.
 //
-// Arguments:
+// Argument List :
 //   roSim - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -949,12 +784,12 @@ bool  PrcNgSpice::bParseSim( Simulation & roSim )
   {
     os1 = roasCmds.Item( sz1 );
 
-    if( bParseCmdOP ( os1, roSim ) ) continue;
-    if( bParseCmdIC ( os1, roSim ) ) continue;
-    if( bParseCmdDC ( os1, roSim ) ) continue;
-    if( bParseCmdAC ( os1, roSim ) ) continue;
-    if( bParseCmdTR ( os1, roSim ) ) continue;
-    if( bParseCmdPR ( os1, roSim ) ) continue;
+    if( bParseCmdOP( os1, roSim ) ) continue;
+    if( bParseCmdIC( os1, roSim ) ) continue;
+    if( bParseCmdDC( os1, roSim ) ) continue;
+    if( bParseCmdAC( os1, roSim ) ) continue;
+    if( bParseCmdTR( os1, roSim ) ) continue;
+    if( bParseCmdPR( os1, roSim ) ) continue;
   }
 
   return( TRUE );
@@ -964,10 +799,10 @@ bool  PrcNgSpice::bParseSim( Simulation & roSim )
 // Create the simulation commands from the values found in a Simulation object
 // and load the command string back into the Simulation object.
 //
-// Arguments:
+// Argument List :
 //   roSim - The simulation object
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
