@@ -2,7 +2,7 @@
 //                                 PnlValue.cpp                               *
 //                                --------------                              *
 //  Started     : 14/09/2004                                                  *
-//  Last Update : 31/08/2007                                                  *
+//  Last Update : 15/02/2008                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -31,7 +31,7 @@ END_EVENT_TABLE( )
 
 //*****************************************************************************
 // Constructor.
-                                                                     
+
 PnlValue::PnlValue( void ) : wxPanel( )
 {
 }
@@ -387,7 +387,7 @@ bool  PnlValue::bSetValue( double dfValue, bool bNoUnits )
   float  fMan=0.0;
   int    iExp=0;
 
-  if( ! bIsCreated( ) ) return( FALSE );
+  if( ! bIsCreated( ) )                              return( FALSE );
 
   fMan = (float) dfValue;
   bTempToDegC( &fMan );  // Convert value to Deg.C  if appropriate
@@ -404,8 +404,8 @@ bool  PnlValue::bSetValue( double dfValue, bool bNoUnits )
     }
 
     // Set the spin control and choice control values
-    if( ! m_oSpnValue.bSetValue( fMan ) )            bRtn = FALSE;
     if( ! m_oChoUnits.bSetUnits( iExp ) )            bRtn = FALSE;
+    else if( ! m_oSpnValue.bSetValue( fMan ) )       bRtn = FALSE;
   }
   else
     if( ! m_oSpnValue.bSetValue( (float) dfValue ) ) bRtn = FALSE;
@@ -558,11 +558,11 @@ const wxString & PnlValue::rosGetName( void )
   static  wxString  os1;
 
   os1.Empty( );
-  
+
   if( ! bIsCreated( ) ) return( os1 );
 
   os1 = m_oLblName.GetLabel( );
-  
+
   return( os1 );
 }
 
